@@ -14,6 +14,7 @@
 #include <openrct2-ui/interface/Widget.h>
 #include <openrct2-ui/windows/Windows.h>
 #include <openrct2/Game.h>
+#include <openrct2/GameState.h>
 #include <openrct2/SpriteIds.h>
 #include <openrct2/actions/BannerRemoveAction.h>
 #include <openrct2/actions/BannerSetNameAction.h>
@@ -24,6 +25,7 @@
 #include <openrct2/object/ObjectEntryManager.h>
 #include <openrct2/ui/WindowManager.h>
 #include <openrct2/world/Banner.h>
+#include <openrct2/world/Map.h>
 #include <openrct2/world/Scenery.h>
 #include <openrct2/world/tile_element/BannerElement.h>
 
@@ -81,16 +83,16 @@ namespace OpenRCT2::Ui::Windows
     private:
         CoordsXYZ _bannerViewPos;
 
-        void CreateViewport()
+        void createViewport()
         {
             const auto& viewportWidget = widgets[WIDX_VIEWPORT];
             ViewportCreate(
-                this, windowPos + ScreenCoordsXY{ viewportWidget.left + 1, viewportWidget.top + 1 },
+                *this, windowPos + ScreenCoordsXY{ viewportWidget.left + 1, viewportWidget.top + 1 },
                 (viewportWidget.width()) - 1, (viewportWidget.height()) - 1, Focus(_bannerViewPos));
 
             if (viewport != nullptr)
                 viewport->flags = Config::Get().general.AlwaysShowGridlines ? VIEWPORT_FLAG_GRIDLINES : VIEWPORT_FLAG_NONE;
-            Invalidate();
+            invalidate();
         }
 
         BannerIndex GetBannerIndex() const
@@ -129,13 +131,13 @@ namespace OpenRCT2::Ui::Windows
         }
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(window_banner_widgets);
+            setWidgets(window_banner_widgets);
             WindowInitScrollWidgets(*this);
         }
 
-        void Initialise(rct_windownumber _number)
+        void initialise(WindowNumber _number)
         {
             number = _number;
             auto* banner = GetBanner(BannerIndex::FromUnderlying(number));
@@ -145,16 +147,16 @@ namespace OpenRCT2::Ui::Windows
                 return;
 
             _bannerViewPos = CoordsXYZ{ banner->position.ToCoordsXY().ToTileCentre(), bannerElement->GetBaseZ() };
-            CreateViewport();
+            createViewport();
         }
 
-        void OnMouseDown(WidgetIndex widgetIndex) override
+        void onMouseDown(WidgetIndex widgetIndex) override
         {
             Widget* widget = &widgets[widgetIndex];
             auto* banner = GetBanner(GetBannerIndex());
             if (banner == nullptr)
             {
-                Close();
+                close();
                 return;
             }
             switch (widgetIndex)
@@ -182,18 +184,21 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             auto* banner = GetBanner(GetBannerIndex());
             if (banner == nullptr)
             {
-                Close();
+                close();
                 return;
             }
+
+            auto& gameState = getGameState();
+
             switch (widgetIndex)
             {
                 case WIDX_CLOSE:
-                    Close();
+                    close();
                     break;
                 case WIDX_BANNER_DEMOLISH:
                 {
@@ -203,7 +208,7 @@ namespace OpenRCT2::Ui::Windows
 
                     auto bannerRemoveAction = GameActions::BannerRemoveAction(
                         { banner->position.ToCoordsXY(), bannerElement->GetBaseZ(), bannerElement->GetPosition() });
-                    GameActions::Execute(&bannerRemoveAction);
+                    GameActions::Execute(&bannerRemoveAction, gameState);
                     break;
                 }
                 case WIDX_BANNER_TEXT:
@@ -215,14 +220,15 @@ namespace OpenRCT2::Ui::Windows
                     TextinputCancel();
                     auto bannerSetStyle = GameActions::BannerSetStyleAction(
                         GameActions::BannerSetStyleType::NoEntry, GetBannerIndex(), !banner->flags.has(BannerFlag::noEntry));
-                    GameActions::Execute(&bannerSetStyle);
+                    GameActions::Execute(&bannerSetStyle, gameState);
                     break;
                 }
             }
         }
 
-        void OnDropdown(WidgetIndex widgetIndex, int32_t dropdownIndex) override
+        void onDropdown(WidgetIndex widgetIndex, int32_t dropdownIndex) override
         {
+            auto& gameState = getGameState();
             switch (widgetIndex)
             {
                 case WIDX_MAIN_COLOUR:
@@ -233,7 +239,7 @@ namespace OpenRCT2::Ui::Windows
                     auto bannerSetStyle = GameActions::BannerSetStyleAction(
                         GameActions::BannerSetStyleType::PrimaryColour, GetBannerIndex(),
                         ColourDropDownIndexToColour(dropdownIndex));
-                    GameActions::Execute(&bannerSetStyle);
+                    GameActions::Execute(&bannerSetStyle, gameState);
                     break;
                 }
                 case WIDX_TEXT_COLOUR_DROPDOWN_BUTTON:
@@ -242,30 +248,30 @@ namespace OpenRCT2::Ui::Windows
                         break;
                     auto bannerSetStyle = GameActions::BannerSetStyleAction(
                         GameActions::BannerSetStyleType::TextColour, GetBannerIndex(), dropdownIndex + 1);
-                    GameActions::Execute(&bannerSetStyle);
+                    GameActions::Execute(&bannerSetStyle, gameState);
                     break;
                 }
             }
         }
 
-        void OnTextInput(WidgetIndex widgetIndex, std::string_view text) override
+        void onTextInput(WidgetIndex widgetIndex, std::string_view text) override
         {
             if (widgetIndex == WIDX_BANNER_TEXT)
             {
                 auto bannerSetNameAction = GameActions::BannerSetNameAction(GetBannerIndex(), std::string(text));
-                GameActions::Execute(&bannerSetNameAction);
+                GameActions::Execute(&bannerSetNameAction, getGameState());
             }
         }
 
-        void OnViewportRotate() override
+        void onViewportRotate() override
         {
-            RemoveViewport();
-            CreateViewport();
+            removeViewport();
+            createViewport();
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(RenderTarget& rt) override
         {
-            DrawWidgets(rt);
+            drawWidgets(rt);
 
             if (viewport != nullptr)
             {
@@ -273,7 +279,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
             auto* banner = GetBanner(GetBannerIndex());
             if (banner == nullptr)
@@ -289,13 +295,13 @@ namespace OpenRCT2::Ui::Windows
             {
                 colourBtn.type = WidgetType::colourBtn;
             }
-            pressed_widgets &= ~(1uLL << WIDX_BANNER_NO_ENTRY);
-            disabled_widgets &= ~(
+            pressedWidgets &= ~(1uLL << WIDX_BANNER_NO_ENTRY);
+            disabledWidgets &= ~(
                 (1uLL << WIDX_BANNER_TEXT) | (1uLL << WIDX_TEXT_COLOUR_DROPDOWN) | (1uLL << WIDX_TEXT_COLOUR_DROPDOWN_BUTTON));
             if (banner->flags.has(BannerFlag::noEntry))
             {
-                pressed_widgets |= (1uLL << WIDX_BANNER_NO_ENTRY);
-                disabled_widgets |= (1uLL << WIDX_BANNER_TEXT) | (1uLL << WIDX_TEXT_COLOUR_DROPDOWN)
+                pressedWidgets |= (1uLL << WIDX_BANNER_NO_ENTRY);
+                disabledWidgets |= (1uLL << WIDX_BANNER_TEXT) | (1uLL << WIDX_TEXT_COLOUR_DROPDOWN)
                     | (1uLL << WIDX_TEXT_COLOUR_DROPDOWN_BUTTON);
             }
             colourBtn.image = getColourButtonImage(banner->colour);
@@ -308,18 +314,18 @@ namespace OpenRCT2::Ui::Windows
      *
      *  rct2: 0x006BA305
      */
-    WindowBase* BannerOpen(rct_windownumber number)
+    WindowBase* BannerOpen(WindowNumber number)
     {
         auto* windowMgr = GetWindowManager();
-        auto w = static_cast<BannerWindow*>(windowMgr->BringToFrontByNumber(WindowClass::Banner, number));
+        auto w = static_cast<BannerWindow*>(windowMgr->BringToFrontByNumber(WindowClass::banner, number));
 
         if (w != nullptr)
             return w;
 
-        w = windowMgr->Create<BannerWindow>(WindowClass::Banner, kWindowSize, 0);
+        w = windowMgr->Create<BannerWindow>(WindowClass::banner, kWindowSize, {});
 
         if (w != nullptr)
-            w->Initialise(number);
+            w->initialise(number);
 
         return w;
     }
