@@ -92,7 +92,8 @@ namespace OpenRCT2::Ui::Windows
         }
 
         // Set research required for rides in use
-        for (const auto& ride : GetRideManager())
+        const auto& gameState = getGameState();
+        for (const auto& ride : RideManager(gameState))
         {
             Editor::SetSelectedObject(
                 ObjectType::ride, ride.subtype, ObjectSelectionFlags::Selected | ObjectSelectionFlags::InUse);
@@ -145,19 +146,19 @@ namespace OpenRCT2::Ui::Windows
         ResearchItem* _selectedResearchItem;
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
             ResearchRidesSetup();
 
-            SetWidgets(_inventionListWidgets);
-            InitScrollWidgets();
-            selected_tab = 0;
+            setWidgets(_inventionListWidgets);
+            initScrollWidgets();
+            selectedTab = 0;
             _selectedResearchItem = nullptr;
 
             WindowSetResize(*this, kWindowSize, { kWindowSize.width * 2, kWindowSize.height * 2 });
         }
 
-        void OnClose() override
+        void onClose() override
         {
             ResearchRemoveFlags();
 
@@ -170,56 +171,56 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnMouseUp(WidgetIndex widx) override
+        void onMouseUp(WidgetIndex widx) override
         {
             switch (widx)
             {
                 case WIDX_CLOSE:
-                    Close();
+                    close();
                     break;
                 case WIDX_RANDOM_SHUFFLE:
                     ResearchItemsShuffle();
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_MOVE_ITEMS_TO_TOP:
                     ResearchItemsMakeAllResearched();
-                    InitScrollWidgets();
-                    Invalidate();
+                    initScrollWidgets();
+                    invalidate();
                     break;
                 case WIDX_MOVE_ITEMS_TO_BOTTOM:
                     ResearchItemsMakeAllUnresearched();
-                    InitScrollWidgets();
-                    Invalidate();
+                    initScrollWidgets();
+                    invalidate();
                     break;
             }
         }
 
-        void OnResize() override
+        void onResize() override
         {
-            if (width < min_width)
+            if (width < minWidth)
             {
-                Invalidate();
-                width = min_width;
+                invalidate();
+                width = minWidth;
             }
-            if (height < min_height)
+            if (height < minHeight)
             {
-                Invalidate();
-                height = min_height;
+                invalidate();
+                height = minHeight;
             }
         }
 
-        void OnUpdate() override
+        void onUpdate() override
         {
-            frame_no++;
-            OnPrepareDraw();
+            currentFrame++;
+            onPrepareDraw();
 
-            InvalidateWidget(WIDX_TAB_1);
+            invalidateWidget(WIDX_TAB_1);
 
             if (WindowEditorInventionsListDragGetItem() != nullptr)
                 return;
         }
 
-        ScreenSize OnScrollGetSize(int32_t scrollIndex) override
+        ScreenSize onScrollGetSize(int32_t scrollIndex) override
         {
             const auto& gameState = getGameState();
             ScreenSize size{};
@@ -234,13 +235,13 @@ namespace OpenRCT2::Ui::Windows
             return size;
         }
 
-        void OnScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             auto* researchItem = GetItemFromScrollY(scrollIndex == 0, screenCoords.y);
             if (researchItem != _selectedResearchItem)
             {
                 _selectedResearchItem = researchItem;
-                Invalidate();
+                invalidate();
 
                 // Prevent always-researched items from being highlighted when hovered over
                 if (researchItem != nullptr && researchItem->IsAlwaysResearched())
@@ -250,7 +251,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             auto* researchItem = GetItemFromScrollY(scrollIndex == 0, screenCoords.y);
             if (researchItem == nullptr)
@@ -260,12 +261,12 @@ namespace OpenRCT2::Ui::Windows
             if (researchItem->IsAlwaysResearched())
                 return;
 
-            Invalidate();
+            invalidate();
 
             WindowEditorInventionsListDragOpen(researchItem, windowPos, widgets[WIDX_PRE_RESEARCHED_SCROLL].right);
         }
 
-        void OnScrollDraw(int32_t scrollIndex, RenderTarget& rt) override
+        void onScrollDraw(int32_t scrollIndex, RenderTarget& rt) override
         {
             const auto& gameState = getGameState();
 
@@ -300,7 +301,7 @@ namespace OpenRCT2::Ui::Windows
                         bottom = itemY;
                     }
 
-                    GfxFilterRect(rt, { 0, top, boxWidth, bottom }, FilterPaletteID::PaletteDarken1);
+                    GfxFilterRect(rt, { 0, top, boxWidth, bottom }, FilterPaletteID::paletteDarken1);
                 }
 
                 if (dragItem != nullptr && researchItem == *dragItem)
@@ -325,7 +326,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        CursorID OnCursor(WidgetIndex widx, const ScreenCoordsXY& screenCoords, CursorID fallback) override
+        CursorID onCursor(WidgetIndex widx, const ScreenCoordsXY& screenCoords, CursorID fallback) override
         {
             bool isInvented = false;
 
@@ -350,13 +351,13 @@ namespace OpenRCT2::Ui::Windows
             return fallback;
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(RenderTarget& rt) override
         {
-            DrawWidgets(rt);
+            drawWidgets(rt);
 
             // Tab image
             auto screenPos = windowPos + ScreenCoordsXY{ widgets[WIDX_TAB_1].left, widgets[WIDX_TAB_1].top };
-            GfxDrawSprite(rt, ImageId(SPR_TAB_FINANCES_RESEARCH_0 + (frame_no / 2) % 8), screenPos);
+            GfxDrawSprite(rt, ImageId(SPR_TAB_FINANCES_RESEARCH_0 + (currentFrame / 2) % 8), screenPos);
 
             // Pre-researched items label
             screenPos = windowPos
@@ -439,10 +440,10 @@ namespace OpenRCT2::Ui::Windows
             DrawTextBasic(rt, screenPos, STR_INVENTION_RESEARCH_GROUP, ft);
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
-            pressed_widgets |= 1uLL << WIDX_PREVIEW;
-            pressed_widgets |= 1uLL << WIDX_TAB_1;
+            pressedWidgets |= 1uLL << WIDX_PREVIEW;
+            pressedWidgets |= 1uLL << WIDX_TAB_1;
 
             widgets[WIDX_CLOSE].type = gLegacyScene == LegacyScene::scenarioEditor ? WidgetType::empty : WidgetType::closeBox;
 
@@ -486,7 +487,7 @@ namespace OpenRCT2::Ui::Windows
                 auto& widget = widgets[widgetIndex];
                 if (widgetIndex == WIDX_PRE_RESEARCHED_SCROLL || widgetIndex == WIDX_RESEARCH_ORDER_SCROLL)
                 {
-                    gPressedWidget.widget_index = widgetIndex;
+                    gPressedWidget.widgetIndex = widgetIndex;
                     int32_t outScrollArea{};
                     ScreenCoordsXY outScrollCoords{};
                     int32_t outScrollId{};
@@ -508,7 +509,7 @@ namespace OpenRCT2::Ui::Windows
             return item == _selectedResearchItem;
         }
 
-        // hack to fix #17544: OnScrollMouseOver never gets called while dragging
+        // hack to fix #17544: onScrollMouseOver never gets called while dragging
         void SetSelectedResearchItem(ResearchItem* item)
         {
             _selectedResearchItem = item;
@@ -518,7 +519,7 @@ namespace OpenRCT2::Ui::Windows
         {
             auto& gameState = getGameState();
             _selectedResearchItem = nullptr;
-            Invalidate();
+            invalidate();
 
             uint32_t beforeItemRawValue = 0;
             if (beforeItem != nullptr)
@@ -587,7 +588,8 @@ namespace OpenRCT2::Ui::Windows
     {
         auto* windowMgr = GetWindowManager();
         return windowMgr->FocusOrCreate<InventionListWindow>(
-            WindowClass::EditorInventionList, kWindowSize, WF_NO_SCROLLING | WF_RESIZABLE | WF_CENTRE_SCREEN);
+            WindowClass::editorInventionList, kWindowSize,
+            { WindowFlag::noScrolling, WindowFlag::resizable, WindowFlag::centreScreen });
     }
 #pragma endregion
 
@@ -598,17 +600,17 @@ namespace OpenRCT2::Ui::Windows
         ResearchItem _draggedItem;
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(_inventionListDragWidgets);
+            setWidgets(_inventionListDragWidgets);
             colours[1] = COLOUR_WHITE;
         }
 
-        CursorID OnCursor(const WidgetIndex widx, const ScreenCoordsXY& screenCoords, const CursorID defaultCursor) override
+        CursorID onCursor(const WidgetIndex widx, const ScreenCoordsXY& screenCoords, const CursorID defaultCursor) override
         {
             auto* windowMgr = GetWindowManager();
             auto* inventionListWindow = static_cast<InventionListWindow*>(
-                windowMgr->FindByClass(WindowClass::EditorInventionList));
+                windowMgr->FindByClass(WindowClass::editorInventionList));
             if (inventionListWindow != nullptr)
             {
                 auto res = inventionListWindow->GetResearchItemAt(screenCoords);
@@ -616,21 +618,21 @@ namespace OpenRCT2::Ui::Windows
                 if (!inventionListWindow->IsResearchItemSelected(research))
                 {
                     inventionListWindow->SetSelectedResearchItem(research);
-                    inventionListWindow->Invalidate();
+                    inventionListWindow->invalidate();
                 }
             }
 
             return CursorID::HandClosed;
         }
 
-        void OnMoved(const ScreenCoordsXY& screenCoords) override
+        void onMoved(const ScreenCoordsXY& screenCoords) override
         {
             auto* windowMgr = GetWindowManager();
             auto* inventionListWindow = static_cast<InventionListWindow*>(
-                windowMgr->FindByClass(WindowClass::EditorInventionList));
+                windowMgr->FindByClass(WindowClass::editorInventionList));
             if (inventionListWindow == nullptr)
             {
-                Close();
+                close();
                 return;
             }
             std::optional<InventionListItem> res;
@@ -647,11 +649,11 @@ namespace OpenRCT2::Ui::Windows
                 inventionListWindow->MoveResearchItem(_draggedItem, res->research, res->isInvented);
             }
 
-            windowMgr->InvalidateByClass(WindowClass::EditorInventionList);
-            Close();
+            windowMgr->InvalidateByClass(WindowClass::editorInventionList);
+            close();
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(RenderTarget& rt) override
         {
             auto screenCoords = windowPos + ScreenCoordsXY{ 0, 2 };
 
@@ -660,15 +662,15 @@ namespace OpenRCT2::Ui::Windows
                 { ColourWithFlags{ COLOUR_BLACK }.withFlag(ColourFlag::withOutline, true) });
         }
 
-        void Init(ResearchItem& researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
+        void init(ResearchItem& researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
         {
             _draggedItem = researchItem;
 
             widgets[0].right = objectSelectionScrollWidth;
-            Invalidate();
+            invalidate();
             windowPos = ScreenCoordsXY{ editorPos.x, gTooltipCursor.y - 7 };
             width = objectSelectionScrollWidth;
-            Invalidate();
+            invalidate();
 
             InputWindowPositionBegin(*this, 0, gTooltipCursor);
         }
@@ -683,19 +685,20 @@ namespace OpenRCT2::Ui::Windows
         ResearchItem* researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
     {
         auto* windowMgr = Ui::GetWindowManager();
-        windowMgr->CloseByClass(WindowClass::EditorInventionListDrag);
+        windowMgr->CloseByClass(WindowClass::editorInventionListDrag);
         auto* wnd = windowMgr->Create<InventionDragWindow>(
-            WindowClass::EditorInventionListDrag, { 10, 14 }, WF_STICK_TO_FRONT | WF_TRANSPARENT | WF_NO_SNAPPING);
+            WindowClass::editorInventionListDrag, { 10, 14 },
+            { WindowFlag::stickToFront, WindowFlag::transparent, WindowFlag::noSnapping });
         if (wnd != nullptr)
         {
-            wnd->Init(*researchItem, editorPos, objectSelectionScrollWidth);
+            wnd->init(*researchItem, editorPos, objectSelectionScrollWidth);
         }
     }
 
     static const ResearchItem* WindowEditorInventionsListDragGetItem()
     {
         auto* windowMgr = GetWindowManager();
-        auto* wnd = static_cast<InventionDragWindow*>(windowMgr->FindByClass(WindowClass::EditorInventionListDrag));
+        auto* wnd = static_cast<InventionDragWindow*>(windowMgr->FindByClass(WindowClass::editorInventionListDrag));
         if (wnd == nullptr)
         {
             return nullptr;
