@@ -27,10 +27,8 @@
 
 namespace OpenRCT2::Ui::Windows
 {
-    static constexpr int32_t WH_DEVELOPMENT = 196;
-    static constexpr int32_t WW_DEVELOPMENT = 300;
-    static constexpr int32_t WH_FUNDING = 207;
-    static constexpr int32_t WW_FUNDING = 320;
+    static constexpr ScreenSize kWindowSizeDevelopment = { 300, 196 };
+    static constexpr ScreenSize kWindowSizeFunding = { 320, 207 };
 
     enum
     {
@@ -52,7 +50,7 @@ namespace OpenRCT2::Ui::Windows
         WIDX_LAST_DEVELOPMENT_GROUP,
         WIDX_LAST_DEVELOPMENT_BUTTON,
 
-        WIDX_FUNDING_GROUP = 6,
+        WIDX_RESEARCH_FUNDING_GROUP = 6,
         WIDX_RESEARCH_FUNDING,
         WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON,
         WIDX_PRIORITIES_GROUP,
@@ -68,33 +66,33 @@ namespace OpenRCT2::Ui::Windows
 #pragma region Widgets
 
     // clang-format off
-    static constexpr Widget window_research_development_widgets[] = {
-        WINDOW_SHIM(STR_RESEARCH_AND_DEVELOPMENT, WW_DEVELOPMENT, WH_DEVELOPMENT),
-        MakeWidget({  0,  43}, {     WW_DEVELOPMENT, 153}, WindowWidgetType::Resize,   WindowColour::Secondary                                                                ),
-        MakeTab   ({  3,  17},                                                                                                  STR_RESEARCH_AND_DEVELOPMENT_TIP),
-        MakeTab   ({ 34,  17},                                                                                                  STR_FINANCES_RESEARCH_TIP       ),
-        MakeWidget({  3,  47}, {WW_DEVELOPMENT - 10,  70}, WindowWidgetType::Groupbox, WindowColour::Tertiary , STR_CURRENTLY_IN_DEVELOPMENT                                  ),
-        MakeWidget({  3, 124}, {WW_DEVELOPMENT - 10,  65}, WindowWidgetType::Groupbox, WindowColour::Tertiary , STR_LAST_DEVELOPMENT                                          ),
-        MakeWidget({265, 161}, {                 24,  24}, WindowWidgetType::FlatBtn,  WindowColour::Tertiary , 0xFFFFFFFF,                   STR_RESEARCH_SHOW_DETAILS_TIP   ),
-    };
+    static constexpr auto window_research_development_widgets = makeWidgets(
+        makeWindowShim(STR_RESEARCH_AND_DEVELOPMENT, kWindowSizeDevelopment),
+        makeWidget({  0,  43}, {     kWindowSizeDevelopment.width, 153}, WidgetType::resize,   WindowColour::secondary                                                                 ),
+        makeTab   ({  3,  17},                                                                                          STR_RESEARCH_AND_DEVELOPMENT_TIP                               ),
+        makeTab   ({ 34,  17},                                                                                          STR_FINANCES_RESEARCH_TIP                                      ),
+        makeWidget({  3,  47}, {kWindowSizeDevelopment.width - 10,  70}, WidgetType::groupbox, WindowColour::tertiary,  STR_CURRENTLY_IN_DEVELOPMENT                                   ),
+        makeWidget({  3, 124}, {kWindowSizeDevelopment.width - 10,  65}, WidgetType::groupbox, WindowColour::tertiary,  STR_LAST_DEVELOPMENT                                           ),
+        makeWidget({265, 161}, {                               24,  24}, WidgetType::flatBtn,  WindowColour::tertiary,  0xFFFFFFFF,                       STR_RESEARCH_SHOW_DETAILS_TIP)
+    );
 
-    static constexpr Widget window_research_funding_widgets[] = {
-        WINDOW_SHIM(STR_RESEARCH_FUNDING, WW_FUNDING, WH_FUNDING),
-        MakeWidget({  0,  43}, {     WW_FUNDING, 164}, WindowWidgetType::Resize,   WindowColour::Secondary                                                                                    ),
-        MakeTab   ({  3,  17},                                                                                                      STR_RESEARCH_AND_DEVELOPMENT_TIP            ),
-        MakeTab   ({ 34,  17},                                                                                                      STR_FINANCES_RESEARCH_TIP                   ),
-        MakeWidget({  3,  47}, { WW_FUNDING - 6,  45}, WindowWidgetType::Groupbox, WindowColour::Tertiary , STR_RESEARCH_FUNDING_                                                             ),
-        MakeWidget({  8,  59}, {            160,  14}, WindowWidgetType::DropdownMenu, WindowColour::Tertiary , 0xFFFFFFFF,                           STR_SELECT_LEVEL_OF_RESEARCH_AND_DEVELOPMENT),
-        MakeWidget({156,  60}, {             11,  12}, WindowWidgetType::Button,   WindowColour::Tertiary , STR_DROPDOWN_GLYPH,                   STR_SELECT_LEVEL_OF_RESEARCH_AND_DEVELOPMENT),
-        MakeWidget({  3,  96}, { WW_FUNDING - 6, 107}, WindowWidgetType::Groupbox, WindowColour::Tertiary , STR_RESEARCH_PRIORITIES                                                           ),
-        MakeWidget({  8, 108}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_TRANSPORT_RIDES,     STR_RESEARCH_NEW_TRANSPORT_RIDES_TIP        ),
-        MakeWidget({  8, 121}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_GENTLE_RIDES,        STR_RESEARCH_NEW_GENTLE_RIDES_TIP           ),
-        MakeWidget({  8, 134}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_ROLLER_COASTERS,     STR_RESEARCH_NEW_ROLLER_COASTERS_TIP        ),
-        MakeWidget({  8, 147}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_THRILL_RIDES,        STR_RESEARCH_NEW_THRILL_RIDES_TIP           ),
-        MakeWidget({  8, 160}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_WATER_RIDES,         STR_RESEARCH_NEW_WATER_RIDES_TIP            ),
-        MakeWidget({  8, 173}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_SHOPS_AND_STALLS,    STR_RESEARCH_NEW_SHOPS_AND_STALLS_TIP       ),
-        MakeWidget({  8, 186}, {WW_FUNDING - 16,  12}, WindowWidgetType::Checkbox, WindowColour::Tertiary , STR_RESEARCH_NEW_SCENERY_AND_THEMING, STR_RESEARCH_NEW_SCENERY_AND_THEMING_TIP    ),
-    };
+    static constexpr auto window_research_funding_widgets = makeWidgets(
+        makeWindowShim(STR_RESEARCH_FUNDING, kWindowSizeFunding),
+        makeWidget({  0,  43}, {     kWindowSizeFunding.width, 164}, WidgetType::resize,       WindowColour::secondary                                                                                   ),
+        makeTab   ({  3,  17},                                                                                         STR_RESEARCH_AND_DEVELOPMENT_TIP                                                  ),
+        makeTab   ({ 34,  17},                                                                                         STR_FINANCES_RESEARCH_TIP                                                         ),
+        makeWidget({  3,  47}, { kWindowSizeFunding.width - 6,  45}, WidgetType::groupbox,     WindowColour::tertiary, STR_RESEARCH_FUNDING_                                                             ),
+        makeWidget({  8,  59}, {                          160,  14}, WidgetType::dropdownMenu, WindowColour::tertiary, 0xFFFFFFFF,                           STR_SELECT_LEVEL_OF_RESEARCH_AND_DEVELOPMENT),
+        makeWidget({156,  60}, {                           11,  12}, WidgetType::button,       WindowColour::tertiary, STR_DROPDOWN_GLYPH,                   STR_SELECT_LEVEL_OF_RESEARCH_AND_DEVELOPMENT),
+        makeWidget({  3,  96}, { kWindowSizeFunding.width - 6, 107}, WidgetType::groupbox,     WindowColour::tertiary, STR_RESEARCH_PRIORITIES                                                           ),
+        makeWidget({  8, 108}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_TRANSPORT_RIDES,     STR_RESEARCH_NEW_TRANSPORT_RIDES_TIP        ),
+        makeWidget({  8, 121}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_GENTLE_RIDES,        STR_RESEARCH_NEW_GENTLE_RIDES_TIP           ),
+        makeWidget({  8, 134}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_ROLLER_COASTERS,     STR_RESEARCH_NEW_ROLLER_COASTERS_TIP        ),
+        makeWidget({  8, 147}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_THRILL_RIDES,        STR_RESEARCH_NEW_THRILL_RIDES_TIP           ),
+        makeWidget({  8, 160}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_WATER_RIDES,         STR_RESEARCH_NEW_WATER_RIDES_TIP            ),
+        makeWidget({  8, 173}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_SHOPS_AND_STALLS,    STR_RESEARCH_NEW_SHOPS_AND_STALLS_TIP       ),
+        makeWidget({  8, 186}, {kWindowSizeFunding.width - 16,  12}, WidgetType::checkbox,     WindowColour::tertiary, STR_RESEARCH_NEW_SCENERY_AND_THEMING, STR_RESEARCH_NEW_SCENERY_AND_THEMING_TIP    )
+    );
 
     static constexpr std::span<const Widget> window_research_page_widgets[] = {
         window_research_development_widgets,
@@ -119,65 +117,62 @@ namespace OpenRCT2::Ui::Windows
     class ResearchWindow final : public Window
     {
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetPage(WINDOW_RESEARCH_PAGE_DEVELOPMENT);
-            width = WW_DEVELOPMENT;
-            height = WH_DEVELOPMENT;
+            setPage(WINDOW_RESEARCH_PAGE_DEVELOPMENT);
             ResearchUpdateUncompletedTypes();
         }
 
-        void SetPage(int32_t newPageIndex)
+        void setPage(int32_t newPageIndex)
         {
+            if (page == newPageIndex && !widgets.empty())
+                return;
+
             page = newPageIndex;
-            frame_no = 0;
-            RemoveViewport();
+            currentFrame = 0;
 
-            hold_down_widgets = 0;
-            SetWidgets(window_research_page_widgets[newPageIndex]);
-            disabled_widgets = 0;
-            pressed_widgets = 0;
-
-            Invalidate();
+            invalidate();
             if (newPageIndex == WINDOW_RESEARCH_PAGE_DEVELOPMENT)
             {
-                width = WW_DEVELOPMENT;
-                height = WH_DEVELOPMENT;
+                width = kWindowSizeDevelopment.width;
+                height = kWindowSizeDevelopment.height;
             }
             else
             {
-                width = WW_FUNDING;
-                height = WH_FUNDING;
+                width = kWindowSizeFunding.width;
+                height = kWindowSizeFunding.height;
             }
-            OnResize();
+            invalidate();
 
-            InitScrollWidgets();
-            Invalidate();
+            setWidgets(window_research_page_widgets[newPageIndex]);
+            holdDownWidgets = 0;
+            disabledWidgets = 0;
+            pressedWidgets = 0;
         }
 
     private:
-        void OnUpdate() override
+        void onUpdate() override
         {
             // Tab animation
-            if (++frame_no >= window_research_tab_animation_loops[page])
-                frame_no = 0;
+            if (++currentFrame >= window_research_tab_animation_loops[page])
+                currentFrame = 0;
 
             switch (page)
             {
                 case WINDOW_RESEARCH_PAGE_DEVELOPMENT:
                 {
-                    InvalidateWidget(WIDX_TAB_1);
+                    invalidateWidget(WIDX_TAB_1);
                     break;
                 }
                 case WINDOW_RESEARCH_PAGE_FUNDING:
                 {
-                    InvalidateWidget(WIDX_TAB_2);
+                    invalidateWidget(WIDX_TAB_2);
                     break;
                 }
             }
         }
 
-        void OnMouseDown(WidgetIndex widgetIndex) override
+        void onMouseDown(WidgetIndex widgetIndex) override
         {
             if (page == WINDOW_RESEARCH_PAGE_FUNDING)
             {
@@ -185,20 +180,20 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             // Switch tab or close
             switch (widgetIndex)
             {
                 case WIDX_CLOSE:
                 {
-                    Close();
+                    close();
                     break;
                 }
                 case WIDX_TAB_1:
                 case WIDX_TAB_2:
                 {
-                    SetPage(widgetIndex - WIDX_TAB_1);
+                    setPage(widgetIndex - WIDX_TAB_1);
                     break;
                 }
             }
@@ -219,7 +214,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnDropdown(WidgetIndex widgetIndex, int32_t selectedIndex) override
+        void onDropdown(WidgetIndex widgetIndex, int32_t selectedIndex) override
         {
             if (page == WINDOW_RESEARCH_PAGE_FUNDING)
             {
@@ -227,14 +222,14 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
             for (auto i = 0; i < WINDOW_RESEARCH_PAGE_COUNT; i++)
             {
-                SetWidgetPressed(WIDX_TAB_1 + i, false);
+                setWidgetPressed(WIDX_TAB_1 + i, false);
             }
 
-            SetWidgetPressed(WIDX_TAB_1 + page, true);
+            setWidgetPressed(WIDX_TAB_1 + page, true);
 
             switch (page)
             {
@@ -251,63 +246,59 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        void onDraw(RenderTarget& rt) override
         {
-            DrawWidgets(dpi);
-            DrawTabImages(dpi);
+            drawWidgets(rt);
+            DrawTabImages(rt);
 
             switch (page)
             {
                 case WINDOW_RESEARCH_PAGE_DEVELOPMENT:
                 {
-                    WindowResearchDevelopmentDraw(this, dpi, WIDX_CURRENTLY_IN_DEVELOPMENT_GROUP);
+                    WindowResearchDevelopmentDraw(this, rt, WIDX_CURRENTLY_IN_DEVELOPMENT_GROUP);
                     break;
                 }
                 case WINDOW_RESEARCH_PAGE_FUNDING:
                 {
-                    WindowResearchFundingDraw(this, dpi);
+                    WindowResearchFundingDraw(this, rt);
                     break;
                 }
             }
         }
 
-        void OnResize() override
-        {
-            ResizeFrameWithPage();
-        }
-
-        void DrawTabImage(DrawPixelInfo& dpi, int32_t tabPage, int32_t spriteIndex)
+        void DrawTabImage(RenderTarget& rt, int32_t tabPage, int32_t spriteIndex)
         {
             WidgetIndex widgetIndex = WIDX_TAB_1 + tabPage;
 
-            if (!IsWidgetDisabled(widgetIndex))
+            if (!isWidgetDisabled(widgetIndex))
             {
                 if (page == tabPage)
                 {
-                    int32_t frame = frame_no / 2;
+                    int32_t frame = currentFrame / 2;
                     if (tabPage == WINDOW_RESEARCH_PAGE_DEVELOPMENT)
                         frame %= 8;
                     spriteIndex += frame;
                 }
 
                 GfxDrawSprite(
-                    dpi, ImageId(spriteIndex),
+                    rt, ImageId(spriteIndex),
                     windowPos + ScreenCoordsXY{ widgets[widgetIndex].left, widgets[widgetIndex].top });
             }
         }
 
-        void DrawTabImages(DrawPixelInfo& dpi)
+        void DrawTabImages(RenderTarget& rt)
         {
-            DrawTabImage(dpi, WINDOW_RESEARCH_PAGE_DEVELOPMENT, SPR_TAB_FINANCES_RESEARCH_0);
-            DrawTabImage(dpi, WINDOW_RESEARCH_PAGE_FUNDING, SPR_TAB_FINANCES_SUMMARY_0);
+            DrawTabImage(rt, WINDOW_RESEARCH_PAGE_DEVELOPMENT, SPR_TAB_FINANCES_RESEARCH_0);
+            DrawTabImage(rt, WINDOW_RESEARCH_PAGE_FUNDING, SPR_TAB_FINANCES_SUMMARY_0);
         }
     };
 
     WindowBase* ResearchOpen()
     {
         auto* windowMgr = GetWindowManager();
-        auto* window = windowMgr->FocusOrCreate<ResearchWindow>(WindowClass::Research, WW_FUNDING, WH_FUNDING, WF_10);
-        window->SetPage(WINDOW_RESEARCH_PAGE_DEVELOPMENT);
+        auto* window = windowMgr->FocusOrCreate<ResearchWindow>(
+            WindowClass::research, kWindowSizeDevelopment, WindowFlag::higherContrastOnPress);
+        window->setPage(WINDOW_RESEARCH_PAGE_DEVELOPMENT);
         return window;
     }
 
@@ -323,152 +314,152 @@ namespace OpenRCT2::Ui::Windows
 
     void WindowResearchDevelopmentMouseUp(WidgetIndex widgetIndex, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_CURRENTLY_IN_DEVELOPMENT_GROUP);
 
         if (widgetIndex == (WIDX_LAST_DEVELOPMENT_BUTTON + widgetOffset))
         {
-            News::OpenSubject(News::ItemType::Research, gameState.ResearchLastItem->rawValue);
+            News::OpenSubject(News::ItemType::research, gameState.researchLastItem->rawValue);
         }
     }
 
     void WindowResearchDevelopmentPrepareDraw(WindowBase* w, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
         // Offset the widget index to allow reuse from other windows
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_CURRENTLY_IN_DEVELOPMENT_GROUP);
-        w->widgets[WIDX_LAST_DEVELOPMENT_BUTTON + widgetOffset].type = WindowWidgetType::Empty;
+        w->widgets[WIDX_LAST_DEVELOPMENT_BUTTON + widgetOffset].type = WidgetType::empty;
 
         // Display button to link to the last development, if there is one
-        if (gameState.ResearchLastItem.has_value())
+        if (gameState.researchLastItem.has_value())
         {
-            auto type = gameState.ResearchLastItem->type;
-            w->widgets[WIDX_LAST_DEVELOPMENT_BUTTON + widgetOffset].type = WindowWidgetType::FlatBtn;
+            auto type = gameState.researchLastItem->type;
+            w->widgets[WIDX_LAST_DEVELOPMENT_BUTTON + widgetOffset].type = WidgetType::flatBtn;
             const auto image = type == Research::EntryType::Ride ? SPR_NEW_RIDE : SPR_NEW_SCENERY;
             w->widgets[WIDX_LAST_DEVELOPMENT_BUTTON + widgetOffset].image = ImageId(image);
         }
     }
 
-    void WindowResearchDevelopmentDraw(WindowBase* w, DrawPixelInfo& dpi, WidgetIndex baseWidgetIndex)
+    void WindowResearchDevelopmentDraw(WindowBase* w, RenderTarget& rt, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
 
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_CURRENTLY_IN_DEVELOPMENT_GROUP);
         auto screenCoords = w->windowPos
             + ScreenCoordsXY{ 10, w->widgets[WIDX_CURRENTLY_IN_DEVELOPMENT_GROUP + widgetOffset].top + 12 };
 
-        if (gameState.ResearchProgressStage == RESEARCH_STAGE_FINISHED_ALL)
+        if (gameState.researchProgressStage == RESEARCH_STAGE_FINISHED_ALL)
         {
             // Research type
             auto ft = Formatter();
             ft.Add<StringId>(STR_RESEARCH_UNKNOWN);
-            DrawTextWrapped(dpi, screenCoords, 296, STR_RESEARCH_TYPE_LABEL, ft);
+            DrawTextWrapped(rt, screenCoords, 296, STR_RESEARCH_TYPE_LABEL, ft);
             screenCoords.y += 25;
 
             // Progress
             ft = Formatter();
             ft.Add<StringId>(STR_RESEARCH_COMPLETED_AL);
-            DrawTextWrapped(dpi, screenCoords, 296, STR_RESEARCH_PROGRESS_LABEL, ft);
+            DrawTextWrapped(rt, screenCoords, 296, STR_RESEARCH_PROGRESS_LABEL, ft);
             screenCoords.y += 15;
 
             // Expected
             ft = Formatter();
             ft.Add<StringId>(STR_RESEARCH_STAGE_UNKNOWN);
-            DrawTextBasic(dpi, screenCoords, STR_RESEARCH_EXPECTED_LABEL, ft);
+            DrawTextBasic(rt, screenCoords, STR_RESEARCH_EXPECTED_LABEL, ft);
         }
         else
         {
             // Research type
             auto ft = Formatter();
             StringId label = STR_RESEARCH_TYPE_LABEL;
-            if (gameState.ResearchProgressStage == RESEARCH_STAGE_INITIAL_RESEARCH)
+            if (gameState.researchProgressStage == RESEARCH_STAGE_INITIAL_RESEARCH)
             {
                 ft.Add<StringId>(STR_RESEARCH_UNKNOWN);
             }
-            else if (gameState.ResearchProgressStage == RESEARCH_STAGE_DESIGNING)
+            else if (gameState.researchProgressStage == RESEARCH_STAGE_DESIGNING)
             {
-                ft.Add<StringId>(gameState.ResearchNextItem->GetCategoryName());
+                ft.Add<StringId>(gameState.researchNextItem->GetCategoryName());
             }
-            else if (gameState.ResearchNextItem->type == Research::EntryType::Ride)
+            else if (gameState.researchNextItem->type == Research::EntryType::Ride)
             {
-                const auto& rtd = GetRideTypeDescriptor(gameState.ResearchNextItem->baseRideType);
+                const auto& rtd = GetRideTypeDescriptor(gameState.researchNextItem->baseRideType);
                 if (rtd.HasFlag(RtdFlag::listVehiclesSeparately))
                 {
-                    ft.Add<StringId>(gameState.ResearchNextItem->GetName());
+                    ft.Add<StringId>(gameState.researchNextItem->GetName());
                 }
-                else if (gameState.ResearchNextItem->flags & RESEARCH_ENTRY_FLAG_FIRST_OF_TYPE)
+                else if (gameState.researchNextItem->flags & RESEARCH_ENTRY_FLAG_FIRST_OF_TYPE)
                 {
                     ft.Add<StringId>(rtd.Naming.Name);
                 }
                 else
                 {
-                    ft.Add<StringId>(gameState.ResearchNextItem->GetName());
+                    ft.Add<StringId>(gameState.researchNextItem->GetName());
                     ft.Add<StringId>(rtd.Naming.Name);
                     label = STR_RESEARCH_TYPE_LABEL_VEHICLE;
                 }
             }
             else
             {
-                ft.Add<StringId>(gameState.ResearchNextItem->GetName());
+                ft.Add<StringId>(gameState.researchNextItem->GetName());
             }
-            DrawTextWrapped(dpi, screenCoords, 296, label, ft);
+            DrawTextWrapped(rt, screenCoords, 296, label, ft);
             screenCoords.y += 25;
 
             // Progress
             ft = Formatter();
-            ft.Add<StringId>(ResearchStageNames[gameState.ResearchProgressStage]);
-            DrawTextWrapped(dpi, screenCoords, 296, STR_RESEARCH_PROGRESS_LABEL, ft);
+            ft.Add<StringId>(ResearchStageNames[gameState.researchProgressStage]);
+            DrawTextWrapped(rt, screenCoords, 296, STR_RESEARCH_PROGRESS_LABEL, ft);
             screenCoords.y += 15;
 
             // Expected
             ft = Formatter();
-            if (gameState.ResearchProgressStage != RESEARCH_STAGE_INITIAL_RESEARCH && gameState.ResearchExpectedDay != 255)
+            if (gameState.researchProgressStage != RESEARCH_STAGE_INITIAL_RESEARCH && gameState.researchExpectedDay != 255)
             {
                 // TODO: Should probably use game date format setting
                 ft.Add<StringId>(STR_RESEARCH_EXPECTED_FORMAT);
-                ft.Add<StringId>(DateDayNames[gameState.ResearchExpectedDay]);
-                ft.Add<StringId>(DateGameMonthNames[gameState.ResearchExpectedMonth]);
+                ft.Add<StringId>(DateDayNames[gameState.researchExpectedDay]);
+                ft.Add<StringId>(DateGameMonthNames[gameState.researchExpectedMonth]);
             }
             else
             {
                 ft.Add<StringId>(STR_RESEARCH_STAGE_UNKNOWN);
             }
-            DrawTextBasic(dpi, screenCoords, STR_RESEARCH_EXPECTED_LABEL, ft);
+            DrawTextBasic(rt, screenCoords, STR_RESEARCH_EXPECTED_LABEL, ft);
         }
 
         // Last development
         screenCoords = w->windowPos + ScreenCoordsXY{ 10, w->widgets[WIDX_LAST_DEVELOPMENT_GROUP + widgetOffset].top + 12 };
 
-        if (gameState.ResearchLastItem.has_value())
+        if (gameState.researchLastItem.has_value())
         {
             StringId lastDevelopmentFormat = kStringIdEmpty;
             auto ft = Formatter();
-            if (gameState.ResearchLastItem->type == Research::EntryType::Scenery)
+            if (gameState.researchLastItem->type == Research::EntryType::Scenery)
             {
                 lastDevelopmentFormat = STR_RESEARCH_SCENERY_LABEL;
-                ft.Add<StringId>(gameState.ResearchLastItem->GetName());
+                ft.Add<StringId>(gameState.researchLastItem->GetName());
             }
             else
             {
                 lastDevelopmentFormat = STR_RESEARCH_RIDE_LABEL;
-                const auto& rtd = GetRideTypeDescriptor(gameState.ResearchLastItem->baseRideType);
+                const auto& rtd = GetRideTypeDescriptor(gameState.researchLastItem->baseRideType);
                 if (rtd.HasFlag(RtdFlag::listVehiclesSeparately))
                 {
-                    ft.Add<StringId>(gameState.ResearchLastItem->GetName());
+                    ft.Add<StringId>(gameState.researchLastItem->GetName());
                 }
-                else if (gameState.ResearchLastItem->flags & RESEARCH_ENTRY_FLAG_FIRST_OF_TYPE)
+                else if (gameState.researchLastItem->flags & RESEARCH_ENTRY_FLAG_FIRST_OF_TYPE)
                 {
                     ft.Add<StringId>(rtd.Naming.Name);
                 }
                 else
                 {
-                    ft.Add<StringId>(gameState.ResearchLastItem->GetName());
+                    ft.Add<StringId>(gameState.researchLastItem->GetName());
                     ft.Add<StringId>(rtd.Naming.Name);
                     lastDevelopmentFormat = STR_RESEARCH_VEHICLE_LABEL;
                 }
             }
 
-            DrawTextWrapped(dpi, screenCoords, 266, lastDevelopmentFormat, ft);
+            DrawTextWrapped(rt, screenCoords, 266, lastDevelopmentFormat, ft);
         }
     }
 
@@ -478,7 +469,7 @@ namespace OpenRCT2::Ui::Windows
 
     void WindowResearchFundingMouseDown(WindowBase* w, WidgetIndex widgetIndex, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_RESEARCH_FUNDING);
 
         if (widgetIndex != (WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON + widgetOffset))
@@ -488,20 +479,19 @@ namespace OpenRCT2::Ui::Windows
 
         for (std::size_t i = 0; i < std::size(kResearchFundingLevelNames); i++)
         {
-            gDropdownItems[i].Format = STR_DROPDOWN_MENU_LABEL;
-            gDropdownItems[i].Args = kResearchFundingLevelNames[i];
+            gDropdown.items[i] = Dropdown::MenuLabel(kResearchFundingLevelNames[i]);
         }
         WindowDropdownShowTextCustomWidth(
             { w->windowPos.x + dropdownWidget->left, w->windowPos.y + dropdownWidget->top }, dropdownWidget->height() + 1,
             w->colours[1], 0, Dropdown::Flag::StayOpen, 4, dropdownWidget->width() - 3);
 
-        int32_t currentResearchLevel = gameState.ResearchFundingLevel;
-        Dropdown::SetChecked(currentResearchLevel, true);
+        int32_t currentResearchLevel = gameState.researchFundingLevel;
+        gDropdown.items[currentResearchLevel].setChecked(true);
     }
 
     void WindowResearchFundingMouseUp(WidgetIndex widgetIndex, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_RESEARCH_FUNDING);
 
         switch (widgetIndex - widgetOffset)
@@ -514,10 +504,11 @@ namespace OpenRCT2::Ui::Windows
             case WIDX_SHOPS_AND_STALLS:
             case WIDX_SCENERY_AND_THEMING:
             {
-                auto activeResearchTypes = gameState.ResearchPriorities;
+                auto activeResearchTypes = gameState.researchPriorities;
                 activeResearchTypes ^= 1uLL << (widgetIndex - (WIDX_TRANSPORT_RIDES + widgetOffset));
-                auto gameAction = ParkSetResearchFundingAction(activeResearchTypes, gameState.ResearchFundingLevel);
-                GameActions::Execute(&gameAction);
+                auto gameAction = GameActions::ParkSetResearchFundingAction(
+                    activeResearchTypes, gameState.researchFundingLevel);
+                GameActions::Execute(&gameAction, getGameState());
                 break;
             }
         }
@@ -525,39 +516,39 @@ namespace OpenRCT2::Ui::Windows
 
     void WindowResearchFundingDropdown(WidgetIndex widgetIndex, int32_t selectedIndex, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_RESEARCH_FUNDING);
 
         if (widgetIndex != (WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON + widgetOffset) || selectedIndex == -1)
             return;
 
-        auto gameAction = ParkSetResearchFundingAction(gameState.ResearchPriorities, selectedIndex);
-        GameActions::Execute(&gameAction);
+        auto gameAction = GameActions::ParkSetResearchFundingAction(gameState.researchPriorities, selectedIndex);
+        GameActions::Execute(&gameAction, getGameState());
     }
 
     void WindowResearchFundingPrepareDraw(WindowBase* w, WidgetIndex baseWidgetIndex)
     {
-        const auto& gameState = GetGameState();
+        const auto& gameState = getGameState();
         auto widgetOffset = GetWidgetIndexOffset(baseWidgetIndex, WIDX_RESEARCH_FUNDING);
 
-        if ((gameState.Park.Flags & PARK_FLAGS_NO_MONEY) || gameState.ResearchProgressStage == RESEARCH_STAGE_FINISHED_ALL)
+        if ((gameState.park.flags & PARK_FLAGS_NO_MONEY) || gameState.researchProgressStage == RESEARCH_STAGE_FINISHED_ALL)
         {
-            w->widgets[WIDX_RESEARCH_FUNDING + widgetOffset].type = WindowWidgetType::Empty;
-            w->widgets[WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON + widgetOffset].type = WindowWidgetType::Empty;
+            w->widgets[WIDX_RESEARCH_FUNDING + widgetOffset].type = WidgetType::empty;
+            w->widgets[WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON + widgetOffset].type = WidgetType::empty;
         }
         else
         {
-            w->widgets[WIDX_RESEARCH_FUNDING + widgetOffset].type = WindowWidgetType::DropdownMenu;
-            w->widgets[WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON + widgetOffset].type = WindowWidgetType::Button;
+            w->widgets[WIDX_RESEARCH_FUNDING + widgetOffset].type = WidgetType::dropdownMenu;
+            w->widgets[WIDX_RESEARCH_FUNDING_DROPDOWN_BUTTON + widgetOffset].type = WidgetType::button;
         }
 
         // Current funding
-        int32_t currentResearchLevel = gameState.ResearchFundingLevel;
+        int32_t currentResearchLevel = gameState.researchFundingLevel;
         w->widgets[WIDX_RESEARCH_FUNDING + widgetOffset].text = kResearchFundingLevelNames[currentResearchLevel];
 
         // Checkboxes
-        uint8_t activeResearchTypes = gameState.ResearchPriorities;
-        int32_t uncompletedResearchTypes = gameState.ResearchUncompletedCategories;
+        uint8_t activeResearchTypes = gameState.researchPriorities;
+        int32_t uncompletedResearchTypes = gameState.researchUncompletedCategories;
         for (int32_t i = 0; i < 7; i++)
         {
             int32_t mask = 1 << i;
@@ -566,32 +557,33 @@ namespace OpenRCT2::Ui::Windows
             // Set checkbox disabled if research type is complete
             if (uncompletedResearchTypes & mask)
             {
-                w->disabled_widgets &= ~widgetMask;
+                w->disabledWidgets &= ~widgetMask;
 
                 // Set checkbox ticked if research type is active
                 if (activeResearchTypes & mask)
-                    w->pressed_widgets |= widgetMask;
+                    w->pressedWidgets |= widgetMask;
                 else
-                    w->pressed_widgets &= ~widgetMask;
+                    w->pressedWidgets &= ~widgetMask;
             }
             else
             {
-                w->disabled_widgets |= widgetMask;
-                w->pressed_widgets &= ~widgetMask;
+                w->disabledWidgets |= widgetMask;
+                w->pressedWidgets &= ~widgetMask;
             }
         }
     }
 
-    void WindowResearchFundingDraw(WindowBase* w, DrawPixelInfo& dpi)
+    void WindowResearchFundingDraw(WindowBase* w, RenderTarget& rt)
     {
-        const auto& gameState = GetGameState();
-        if (gameState.Park.Flags & PARK_FLAGS_NO_MONEY)
+        const auto& gameState = getGameState();
+        if (gameState.park.flags & PARK_FLAGS_NO_MONEY)
             return;
 
-        int32_t currentResearchLevel = gameState.ResearchFundingLevel;
+        int32_t currentResearchLevel = gameState.researchFundingLevel;
         auto ft = Formatter();
-        ft.Add<money64>(research_cost_table[currentResearchLevel]);
-        DrawTextBasic(dpi, w->windowPos + ScreenCoordsXY{ 10, 77 }, STR_RESEARCH_COST_PER_MONTH, ft);
+        ft.Add<money64>(kResearchCosts[currentResearchLevel]);
+        DrawTextBasic(
+            rt, w->windowPos + ScreenCoordsXY{ 10, w->widgets[WIDX_TAB_1].top + 60 }, STR_RESEARCH_COST_PER_MONTH, ft);
     }
 
 #pragma endregion
