@@ -31,6 +31,8 @@
 #include <openrct2/ride/TrackDesignRepository.h>
 #include <openrct2/ui/WindowManager.h>
 #include <openrct2/windows/Intent.h>
+#include <openrct2/world/Map.h>
+#include <openrct2/world/MapSelection.h>
 #include <openrct2/world/Park.h>
 #include <openrct2/world/tile_element/Slope.h>
 #include <openrct2/world/tile_element/SurfaceElement.h>
@@ -41,17 +43,16 @@ using namespace OpenRCT2::TrackMetaData;
 
 namespace OpenRCT2::Ui::Windows
 {
-    static constexpr StringId WINDOW_TITLE = STR_STRING;
-    static constexpr int32_t WH = 124;
-    static constexpr int32_t WW = 200;
-    constexpr int16_t TRACK_MINI_PREVIEW_WIDTH = 168;
-    constexpr int16_t TRACK_MINI_PREVIEW_HEIGHT = 78;
-    constexpr uint16_t TRACK_MINI_PREVIEW_SIZE = TRACK_MINI_PREVIEW_WIDTH * TRACK_MINI_PREVIEW_HEIGHT;
+    static constexpr StringId kWindowTitle = STR_STRING;
+    static constexpr ScreenSize kWindowSize = { 200, 124 };
+    constexpr int16_t kTrackMiniPreviewWidth = 168;
+    constexpr int16_t kTrackMiniPreviewHeight = 78;
+    constexpr uint16_t kTrackMiniPreviewSize = kTrackMiniPreviewWidth * kTrackMiniPreviewHeight;
 
-    static constexpr uint8_t kPaletteIndexColourEntrance = PALETTE_INDEX_20; // White
-    static constexpr uint8_t kPaletteIndexColourExit = PALETTE_INDEX_10;     // Black
-    static constexpr uint8_t kPaletteIndexColourTrack = PALETTE_INDEX_248;   // Grey (dark)
-    static constexpr uint8_t kPaletteIndexColourStation = PALETTE_INDEX_252; // Grey (light)
+    static constexpr uint8_t kPaletteIndexColourEntrance = PaletteIndex::pi20; // White
+    static constexpr uint8_t kPaletteIndexColourExit = PaletteIndex::pi10;     // Black
+    static constexpr uint8_t kPaletteIndexColourTrack = PaletteIndex::pi248;   // Grey (dark)
+    static constexpr uint8_t kPaletteIndexColourStation = PaletteIndex::pi252; // Grey (light)
 
     enum
     {
@@ -64,16 +65,16 @@ namespace OpenRCT2::Ui::Windows
         WIDX_PRICE
     };
 
-    validate_global_widx(WC_TRACK_DESIGN_PLACE, WIDX_ROTATE);
+    VALIDATE_GLOBAL_WIDX(WC_TRACK_DESIGN_PLACE, WIDX_ROTATE);
 
     // clang-format off
-    static constexpr Widget _trackPlaceWidgets[] = {
-        WINDOW_SHIM(WINDOW_TITLE, WW, WH),
-        MakeWidget({173,  83}, { 24, 24}, WindowWidgetType::FlatBtn, WindowColour::Primary, ImageId(SPR_ROTATE_ARROW),              STR_ROTATE_90_TIP                         ),
-        MakeWidget({173,  59}, { 24, 24}, WindowWidgetType::FlatBtn, WindowColour::Primary, ImageId(SPR_MIRROR_ARROW),              STR_MIRROR_IMAGE_TIP                      ),
-        MakeWidget({  4, 109}, {192, 12}, WindowWidgetType::Button,  WindowColour::Primary, STR_SELECT_A_DIFFERENT_DESIGN, STR_GO_BACK_TO_DESIGN_SELECTION_WINDOW_TIP),
-        MakeWidget({  0,   0}, {  1,  1}, WindowWidgetType::Empty,   WindowColour::Primary),
-    };
+    static constexpr auto _trackPlaceWidgets = makeWidgets(
+        makeWindowShim(kWindowTitle, kWindowSize),
+        makeWidget({173,  83}, { 24, 24}, WidgetType::flatBtn, WindowColour::primary, ImageId(SPR_ROTATE_ARROW),     STR_ROTATE_90_TIP                         ),
+        makeWidget({173,  59}, { 24, 24}, WidgetType::flatBtn, WindowColour::primary, ImageId(SPR_MIRROR_ARROW),     STR_MIRROR_IMAGE_TIP                      ),
+        makeWidget({  4, 109}, {192, 12}, WidgetType::button,  WindowColour::primary, STR_SELECT_A_DIFFERENT_DESIGN, STR_GO_BACK_TO_DESIGN_SELECTION_WINDOW_TIP),
+        makeWidget({  0,   0}, {  1,  1}, WidgetType::empty,   WindowColour::primary)
+    );
     // clang-format on
 
     class TrackDesignPlaceWindow final : public Window
@@ -97,60 +98,61 @@ namespace OpenRCT2::Ui::Windows
         int32_t _trackPlaceShiftZ;
 
         int32_t _trackPlaceZ;
+        bool _triggeredUndergroundView = false;
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(_trackPlaceWidgets);
+            setWidgets(_trackPlaceWidgets);
             WindowInitScrollWidgets(*this);
-            ToolSet(*this, WIDX_PRICE, Tool::Crosshair);
-            InputSetFlag(INPUT_FLAG_6, true);
+            ToolSet(*this, WIDX_PRICE, Tool::crosshair);
+            gInputFlags.set(InputFlag::unk6);
             WindowPushOthersRight(*this);
             ShowGridlines();
-            _miniPreview.resize(TRACK_MINI_PREVIEW_SIZE);
+            _miniPreview.resize(kTrackMiniPreviewSize);
             _placementCost = kMoney64Undefined;
             _placementLoc.SetNull();
             _currentTrackPieceDirection = (2 - GetCurrentRotation()) & 3;
         }
 
-        void OnClose() override
+        void onClose() override
         {
             ClearProvisional();
-            ViewportSetVisibility(ViewportVisibility::Default);
+            ViewportSetVisibility(ViewportVisibility::standard);
             MapInvalidateMapSelectionTiles();
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE_CONSTRUCT;
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE_ARROW;
+            gMapSelectFlags.unset(MapSelectFlag::enableConstruct);
+            gMapSelectFlags.unset(MapSelectFlag::enableArrow);
             HideGridlines();
             _miniPreview.clear();
             _miniPreview.shrink_to_fit();
             _trackDesign = nullptr;
         }
 
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             switch (widgetIndex)
             {
                 case WIDX_CLOSE:
-                    Close();
+                    close();
                     break;
                 case WIDX_ROTATE:
                     ClearProvisional();
                     _currentTrackPieceDirection = (_currentTrackPieceDirection + 1) & 3;
-                    Invalidate();
+                    invalidate();
                     _placementLoc.SetNull();
                     DrawMiniPreview(*_trackDesign);
                     break;
                 case WIDX_MIRROR:
                     TrackDesignMirror(*_trackDesign);
                     _currentTrackPieceDirection = (0 - _currentTrackPieceDirection) & 3;
-                    Invalidate();
+                    invalidate();
                     _placementLoc.SetNull();
                     DrawMiniPreview(*_trackDesign);
                     break;
                 case WIDX_SELECT_DIFFERENT_DESIGN:
-                    Close();
+                    close();
 
-                    auto intent = Intent(WindowClass::TrackDesignList);
+                    auto intent = Intent(WindowClass::trackDesignList);
                     intent.PutExtra(INTENT_EXTRA_RIDE_TYPE, _window_track_list_item.Type);
                     intent.PutExtra(INTENT_EXTRA_RIDE_ENTRY_INDEX, _window_track_list_item.EntryIndex);
                     ContextOpenIntent(&intent);
@@ -158,20 +160,20 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnUpdate() override
+        void onUpdate() override
         {
-            if (!isToolActive(WindowClass::TrackDesignPlace))
-                Close();
+            if (!isToolActive(WindowClass::trackDesignPlace))
+                close();
         }
 
-        void OnToolUpdate(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
+        void onToolUpdate(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
         {
             TrackDesignState tds{};
 
             MapInvalidateMapSelectionTiles();
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE;
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE_CONSTRUCT;
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE_ARROW;
+            gMapSelectFlags.unset(MapSelectFlag::enable);
+            gMapSelectFlags.unset(MapSelectFlag::enableConstruct);
+            gMapSelectFlags.unset(MapSelectFlag::enableArrow);
 
             // Take shift modifier into account
             ScreenCoordsXY targetScreenCoords = screenCoords;
@@ -206,7 +208,7 @@ namespace OpenRCT2::Ui::Windows
             }
 
             money64 cost = kMoney64Undefined;
-            if (GameIsNotPaused() || GetGameState().Cheats.buildInPauseMode)
+            if (GameIsNotPaused() || getGameState().cheats.buildInPauseMode)
             {
                 ClearProvisional();
                 auto res = FindValidTrackDesignPlaceHeight(trackLoc, GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
@@ -214,9 +216,9 @@ namespace OpenRCT2::Ui::Windows
                 if (res.Error == GameActions::Status::Ok)
                 {
                     // Valid location found. Place the ghost at the location.
-                    auto tdAction = TrackDesignAction(trackLoc, *_trackDesign);
+                    auto tdAction = GameActions::TrackDesignAction(trackLoc, *_trackDesign);
                     tdAction.SetFlags(GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-                    tdAction.SetCallback([&](const GameAction*, const GameActions::Result* result) {
+                    tdAction.SetCallback([&](const GameActions::GameAction*, const GameActions::Result* result) {
                         if (result->Error == GameActions::Status::Ok)
                         {
                             _placementGhostRideId = result->GetData<RideId>();
@@ -224,7 +226,7 @@ namespace OpenRCT2::Ui::Windows
                             _hasPlacementGhost = true;
                         }
                     });
-                    res = GameActions::Execute(&tdAction);
+                    res = GameActions::Execute(&tdAction, getGameState());
                     cost = res.Error == GameActions::Status::Ok ? res.Cost : kMoney64Undefined;
 
                     VirtualFloorSetHeight(trackLoc.z);
@@ -235,19 +237,19 @@ namespace OpenRCT2::Ui::Windows
             if (cost != _placementCost)
             {
                 _placementCost = cost;
-                InvalidateWidget(WIDX_PRICE);
+                invalidateWidget(WIDX_PRICE);
             }
 
             TrackDesignPreviewDrawOutlines(tds, *_trackDesign, RideGetTemporaryForPreview(), trackLoc);
         }
 
-        void OnToolDown(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
+        void onToolDown(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
         {
             ClearProvisional();
             MapInvalidateMapSelectionTiles();
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE;
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE_CONSTRUCT;
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE_ARROW;
+            gMapSelectFlags.unset(MapSelectFlag::enable);
+            gMapSelectFlags.unset(MapSelectFlag::enableConstruct);
+            gMapSelectFlags.unset(MapSelectFlag::enableArrow);
 
             // Take shift modifier into account
             ScreenCoordsXY targetScreenCoords = screenCoords;
@@ -276,18 +278,18 @@ namespace OpenRCT2::Ui::Windows
             if (res.Error != GameActions::Status::Ok)
             {
                 // Unable to build track
-                Audio::Play3D(Audio::SoundId::Error, trackLoc);
+                Audio::Play3D(Audio::SoundId::error, trackLoc);
 
                 auto windowManager = GetWindowManager();
                 windowManager->ShowError(res.GetErrorTitle(), res.GetErrorMessage());
                 return;
             }
 
-            auto tdAction = TrackDesignAction({ trackLoc, _currentTrackPieceDirection }, *_trackDesign);
-            tdAction.SetCallback([&](const GameAction*, const GameActions::Result* result) {
+            auto tdAction = GameActions::TrackDesignAction({ trackLoc, _currentTrackPieceDirection }, *_trackDesign);
+            tdAction.SetCallback([&](const GameActions::GameAction*, const GameActions::Result* result) {
                 if (result->Error != GameActions::Status::Ok)
                 {
-                    Audio::Play3D(Audio::SoundId::Error, result->Position);
+                    Audio::Play3D(Audio::SoundId::error, result->Position);
                     return;
                 }
 
@@ -296,78 +298,73 @@ namespace OpenRCT2::Ui::Windows
                 if (getRide != nullptr)
                 {
                     auto* windowMgr = Ui::GetWindowManager();
-                    windowMgr->CloseByClass(WindowClass::Error);
+                    windowMgr->CloseByClass(WindowClass::error);
 
-                    Audio::Play3D(Audio::SoundId::PlaceItem, trackLoc);
+                    Audio::Play3D(Audio::SoundId::placeItem, trackLoc);
                     _currentRideIndex = rideId;
 
                     if (TrackDesignAreEntranceAndExitPlaced())
                     {
-                        auto intent = Intent(WindowClass::Ride);
+                        auto intent = Intent(WindowClass::ride);
                         intent.PutExtra(INTENT_EXTRA_RIDE_ID, rideId.ToUnderlying());
                         ContextOpenIntent(&intent);
-                        auto* wnd = windowMgr->FindByClass(WindowClass::TrackDesignPlace);
+                        auto* wnd = windowMgr->FindByClass(WindowClass::trackDesignPlace);
                         windowMgr->Close(*wnd);
                     }
                     else
                     {
                         RideInitialiseConstructionWindow(*getRide);
-                        auto* wnd = windowMgr->FindByClass(WindowClass::RideConstruction);
-                        wnd->OnMouseUp(WC_RIDE_CONSTRUCTION__WIDX_ENTRANCE);
+                        auto* wnd = windowMgr->FindByClass(WindowClass::rideConstruction);
+                        wnd->onMouseUp(WC_RIDE_CONSTRUCTION__WIDX_ENTRANCE);
                     }
                 }
             });
-            GameActions::Execute(&tdAction);
+            GameActions::Execute(&tdAction, getGameState());
         }
 
-        void OnToolAbort(WidgetIndex widgetIndex) override
+        void onToolAbort(WidgetIndex widgetIndex) override
         {
             ClearProvisional();
         }
 
-        void OnViewportRotate() override
+        void onViewportRotate() override
         {
             DrawMiniPreview(*_trackDesign);
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
             DrawMiniPreview(*_trackDesign);
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        void onDraw(RenderTarget& rt) override
         {
             auto ft = Formatter::Common();
             ft.Add<char*>(_trackDesign->gameStateData.name.c_str());
-            WindowDrawWidgets(*this, dpi);
+            WindowDrawWidgets(*this, rt);
 
             // Draw mini tile preview
-            DrawPixelInfo clippedDpi;
-            if (ClipDrawPixelInfo(clippedDpi, dpi, this->windowPos + ScreenCoordsXY{ 4, 18 }, 168, 78))
+            RenderTarget clippedRT;
+            if (ClipDrawPixelInfo(clippedRT, rt, this->windowPos + ScreenCoordsXY{ 4, 18 }, 168, 78))
             {
                 G1Element g1temp = {};
                 g1temp.offset = _miniPreview.data();
-                g1temp.width = TRACK_MINI_PREVIEW_WIDTH;
-                g1temp.height = TRACK_MINI_PREVIEW_HEIGHT;
+                g1temp.width = kTrackMiniPreviewWidth;
+                g1temp.height = kTrackMiniPreviewHeight;
                 GfxSetG1Element(SPR_TEMP, &g1temp);
                 DrawingEngineInvalidateImage(SPR_TEMP);
-                GfxDrawSprite(clippedDpi, ImageId(SPR_TEMP, this->colours[0].colour), { 0, 0 });
+                GfxDrawSprite(clippedRT, ImageId(SPR_TEMP, this->colours[0].colour), { 0, 0 });
             }
 
             // Price
-            if (_placementCost != kMoney64Undefined && !(GetGameState().Park.Flags & PARK_FLAGS_NO_MONEY))
+            if (_placementCost != kMoney64Undefined && !(getGameState().park.flags & PARK_FLAGS_NO_MONEY))
             {
                 ft = Formatter();
                 ft.Add<money64>(_placementCost);
-                DrawTextBasic(dpi, this->windowPos + ScreenCoordsXY{ 88, 94 }, STR_COST_LABEL, ft, { TextAlignment::CENTRE });
+                DrawTextBasic(rt, this->windowPos + ScreenCoordsXY{ 88, 94 }, STR_COST_LABEL, ft, { TextAlignment::CENTRE });
             }
         }
 
-        void OnResize() override
-        {
-            ResizeFrame();
-        }
-
         void ClearProvisionalTemporarily()
         {
             if (_hasPlacementGhost)
@@ -384,9 +381,9 @@ namespace OpenRCT2::Ui::Windows
         {
             if (_hasPlacementGhost)
             {
-                auto tdAction = TrackDesignAction({ _placementGhostLoc }, *_trackDesign);
+                auto tdAction = GameActions::TrackDesignAction({ _placementGhostLoc }, *_trackDesign);
                 tdAction.SetFlags(GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-                auto res = GameActions::Execute(&tdAction);
+                auto res = GameActions::Execute(&tdAction, getGameState());
                 if (res.Error != GameActions::Status::Ok)
                 {
                     _hasPlacementGhost = false;
@@ -394,7 +391,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void Init(std::unique_ptr<TrackDesign>&& trackDesign)
+        void init(std::unique_ptr<TrackDesign>&& trackDesign)
         {
             _trackDesign = std::move(trackDesign);
         }
@@ -430,7 +427,7 @@ namespace OpenRCT2::Ui::Windows
         void ClearMiniPreview()
         {
             // Fill with transparent colour.
-            std::fill(_miniPreview.begin(), _miniPreview.end(), PALETTE_INDEX_0);
+            std::fill(_miniPreview.begin(), _miniPreview.end(), PaletteIndex::pi0);
         }
 
     private:
@@ -458,14 +455,14 @@ namespace OpenRCT2::Ui::Windows
 
             auto& im = GetInputManager();
 
-            if (!_trackPlaceCtrlState && im.IsModifierKeyPressed(ModifierKey::ctrl))
+            if (!_trackPlaceCtrlState && im.isModifierKeyPressed(ModifierKey::ctrl))
             {
                 constexpr auto interactionFlags = EnumsToFlags(
-                    ViewportInteractionItem::Terrain, ViewportInteractionItem::Ride, ViewportInteractionItem::Scenery,
-                    ViewportInteractionItem::Footpath, ViewportInteractionItem::Wall, ViewportInteractionItem::LargeScenery);
+                    ViewportInteractionItem::terrain, ViewportInteractionItem::ride, ViewportInteractionItem::scenery,
+                    ViewportInteractionItem::footpath, ViewportInteractionItem::wall, ViewportInteractionItem::largeScenery);
 
                 auto info = GetMapCoordinatesFromPos(screenCoords, interactionFlags);
-                if (info.interactionType == ViewportInteractionItem::Terrain)
+                if (info.interactionType == ViewportInteractionItem::terrain)
                 {
                     _trackPlaceCtrlZ = floor2(surfaceElement->GetBaseZ(), kCoordsZStep);
 
@@ -480,21 +477,21 @@ namespace OpenRCT2::Ui::Windows
 
                 _trackPlaceCtrlState = true;
             }
-            else if (!im.IsModifierKeyPressed(ModifierKey::ctrl))
+            else if (!im.isModifierKeyPressed(ModifierKey::ctrl))
             {
                 _trackPlaceCtrlState = false;
                 _trackPlaceCtrlZ = 0;
             }
 
-            if (!_trackPlaceShiftState && im.IsModifierKeyPressed(ModifierKey::shift))
+            if (!_trackPlaceShiftState && im.isModifierKeyPressed(ModifierKey::shift))
             {
                 _trackPlaceShiftState = true;
                 _trackPlaceShiftStart = screenCoords;
                 _trackPlaceShiftZ = 0;
             }
-            else if (im.IsModifierKeyPressed(ModifierKey::shift))
+            else if (im.isModifierKeyPressed(ModifierKey::shift))
             {
-                uint16_t maxHeight = ZoomLevel::max().ApplyTo(
+                uint16_t newMaxHeight = ZoomLevel::max().ApplyTo(
                     std::numeric_limits<decltype(TileElement::BaseHeight)>::max() - 32);
 
                 _trackPlaceShiftZ = _trackPlaceShiftStart.y - screenCoords.y + 4;
@@ -508,7 +505,7 @@ namespace OpenRCT2::Ui::Windows
                 _trackPlaceShiftZ = floor2(_trackPlaceShiftZ, kCoordsZStep);
 
                 // Clamp to maximum possible value of BaseHeight can offer.
-                _trackPlaceShiftZ = std::min<int16_t>(_trackPlaceShiftZ, maxHeight);
+                _trackPlaceShiftZ = std::min<int16_t>(_trackPlaceShiftZ, newMaxHeight);
             }
             else if (_trackPlaceShiftState)
             {
@@ -542,6 +539,27 @@ namespace OpenRCT2::Ui::Windows
             if (mapCoords.x == kLocationNull)
                 return std::nullopt;
 
+            // Trigger underground view?
+            auto* mainWnd = WindowGetMain();
+            if (mainWnd != nullptr && mainWnd->viewport != nullptr)
+            {
+                if (_trackPlaceZ < surfaceElement->GetBaseZ() && !_triggeredUndergroundView)
+                {
+                    mainWnd->viewport->flags |= VIEWPORT_FLAG_UNDERGROUND_INSIDE;
+                    _triggeredUndergroundView = true;
+                }
+                else if (_trackPlaceZ >= surfaceElement->GetBaseZ() && _triggeredUndergroundView)
+                {
+                    mainWnd->viewport->flags &= ~VIEWPORT_FLAG_UNDERGROUND_INSIDE;
+                    _triggeredUndergroundView = false;
+                }
+            }
+
+            // Force placement at the designated position if modifiers are used
+            if (_trackPlaceShiftState || _trackPlaceCtrlState)
+                return _trackPlaceZ;
+
+            // Figure out a good position to place the design, taking other elements and surface height into account
             return _trackPlaceZ
                 + TrackDesignGetZPlacement(
                        *_trackDesign, RideGetTemporaryForPreview(), { mapCoords, _trackPlaceZ, _currentTrackPieceDirection });
@@ -701,7 +719,7 @@ namespace OpenRCT2::Ui::Windows
 
         uint8_t* DrawMiniPreviewGetPixelPtr(const ScreenCoordsXY& pixel)
         {
-            return &_miniPreview[pixel.y * TRACK_MINI_PREVIEW_WIDTH + pixel.x];
+            return &_miniPreview[pixel.y * kTrackMiniPreviewWidth + pixel.x];
         }
 
         GameActions::Result FindValidTrackDesignPlaceHeight(CoordsXYZ& loc, uint32_t newFlags)
@@ -709,10 +727,10 @@ namespace OpenRCT2::Ui::Windows
             GameActions::Result res;
             for (int32_t i = 0; i < 7; i++, loc.z += kCoordsZStep)
             {
-                auto tdAction = TrackDesignAction(
+                auto tdAction = GameActions::TrackDesignAction(
                     CoordsXYZD{ loc.x, loc.y, loc.z, _currentTrackPieceDirection }, *_trackDesign);
                 tdAction.SetFlags(newFlags);
-                res = GameActions::Query(&tdAction);
+                res = GameActions::Query(&tdAction, getGameState());
 
                 // If successful don't keep trying.
                 // If failure due to no money then increasing height only makes problem worse
@@ -737,10 +755,10 @@ namespace OpenRCT2::Ui::Windows
         auto* windowMgr = Ui::GetWindowManager();
         windowMgr->CloseConstructionWindows();
 
-        auto* window = windowMgr->FocusOrCreate<TrackDesignPlaceWindow>(WindowClass::TrackDesignPlace, WW, WH, 0);
+        auto* window = windowMgr->FocusOrCreate<TrackDesignPlaceWindow>(WindowClass::trackDesignPlace, kWindowSize, {});
         if (window != nullptr)
         {
-            window->Init(std::move(openTrackDesign));
+            window->init(std::move(openTrackDesign));
         }
         return window;
     }
@@ -748,7 +766,7 @@ namespace OpenRCT2::Ui::Windows
     void TrackPlaceClearProvisionalTemporarily()
     {
         auto* windowMgr = GetWindowManager();
-        auto* trackPlaceWnd = static_cast<TrackDesignPlaceWindow*>(windowMgr->FindByClass(WindowClass::TrackDesignPlace));
+        auto* trackPlaceWnd = static_cast<TrackDesignPlaceWindow*>(windowMgr->FindByClass(WindowClass::trackDesignPlace));
         if (trackPlaceWnd != nullptr)
         {
             trackPlaceWnd->ClearProvisionalTemporarily();
@@ -758,7 +776,7 @@ namespace OpenRCT2::Ui::Windows
     void TrackPlaceRestoreProvisional()
     {
         auto* windowMgr = GetWindowManager();
-        auto* trackPlaceWnd = static_cast<TrackDesignPlaceWindow*>(windowMgr->FindByClass(WindowClass::TrackDesignPlace));
+        auto* trackPlaceWnd = static_cast<TrackDesignPlaceWindow*>(windowMgr->FindByClass(WindowClass::trackDesignPlace));
         if (trackPlaceWnd != nullptr)
         {
             trackPlaceWnd->RestoreProvisional();
