@@ -18,6 +18,7 @@
 #include "../audio/Audio.h"
 #include "../core/DataSerialiser.h"
 #include "../core/EnumUtils.hpp"
+#include "../entity/EntityList.h"
 #include "../entity/EntityRegistry.h"
 #include "../interface/Viewport.h"
 #include "../localisation/StringIds.h"
@@ -43,7 +44,9 @@
 #include "../windows/Intent.h"
 #include "../world/Entrance.h"
 #include "../world/Footpath.h"
+#include "../world/Map.h"
 #include "../world/Scenery.h"
+#include "../world/Wall.h"
 #include "../world/tile_element/EntranceElement.h"
 #include "../world/tile_element/PathElement.h"
 #include "../world/tile_element/Slope.h"
@@ -58,9 +61,6 @@
 
 using namespace OpenRCT2;
 
-// Maximum manhattan distance that litter can be for a handyman to seek to it
-const uint16_t MAX_LITTER_DISTANCE = 3 * kCoordsXYStep;
-
 template<>
 bool EntityBase::Is<Staff>() const
 {
@@ -319,33 +319,45 @@ bool Staff::HasPatrolArea() const
  *
  *  rct2: 0x006BFBE8
  *
- * Returns INVALID_DIRECTION when no nearby litter or unpathable litter
+ * Returns kInvalidDirection when no nearby litter or unpathable litter
  */
 Direction Staff::HandymanDirectionToNearestLitter() const
 {
-    uint16_t nearestLitterDist = 0xFFFF;
-    Litter* nearestLitter = nullptr;
-    for (auto litter : EntityList<Litter>())
-    {
-        uint16_t distance = abs(litter->x - x) + abs(litter->y - y) + abs(litter->z - z) * 4;
+    // Maximum manhattan distance that litter can be for a handyman to seek to it
+    constexpr auto kTileRadius = 3;
+    constexpr auto kLookupRadius = kCoordsXYStep * kTileRadius;
 
-        if (distance < nearestLitterDist)
+    auto nearestLitterDist = std::numeric_limits<int32_t>::max();
+    Litter* nearestLitter = nullptr;
+
+    for (int32_t tileX = x - kLookupRadius; tileX <= x + kLookupRadius; tileX += kCoordsXYStep)
+    {
+        for (int32_t tileY = y - kLookupRadius; tileY <= y + kLookupRadius; tileY += kCoordsXYStep)
         {
-            nearestLitterDist = distance;
-            nearestLitter = litter;
+            for (auto* litter : EntityTileList<Litter>({ tileX, tileY }))
+            {
+                // Calculate Manhattan distance with z-weighting
+                uint16_t distance = std::abs(litter->x - x) + std::abs(litter->y - y) + std::abs(litter->z - z) * 4;
+
+                if (distance < nearestLitterDist)
+                {
+                    nearestLitterDist = distance;
+                    nearestLitter = litter;
+                }
+            }
         }
     }
 
-    if (nearestLitterDist > MAX_LITTER_DISTANCE)
+    if (nearestLitterDist > kLookupRadius || nearestLitter == nullptr)
     {
-        return INVALID_DIRECTION;
+        return kInvalidDirection;
     }
 
     auto litterTile = CoordsXY{ nearestLitter->x, nearestLitter->y }.ToTileStart();
 
     if (!IsLocationInPatrol(litterTile))
     {
-        return INVALID_DIRECTION;
+        return kInvalidDirection;
     }
 
     Direction nextDirection = DirectionFromTo(CoordsXY(x, y), litterTile.ToTileCentre());
@@ -356,14 +368,14 @@ Direction Staff::HandymanDirectionToNearestLitter() const
 
     TileElement* tileElement = MapGetFirstElementAt(nextTile);
     if (tileElement == nullptr)
-        return INVALID_DIRECTION;
+        return kInvalidDirection;
     do
     {
         if (tileElement->BaseHeight != nextZ)
             continue;
         if (tileElement->GetType() == TileElementType::Entrance || tileElement->GetType() == TileElementType::Track)
         {
-            return INVALID_DIRECTION;
+            return kInvalidDirection;
         }
     } while (!(tileElement++)->IsLastForTile());
 
@@ -371,7 +383,7 @@ Direction Staff::HandymanDirectionToNearestLitter() const
 
     tileElement = MapGetFirstElementAt(nextTile);
     if (tileElement == nullptr)
-        return INVALID_DIRECTION;
+        return kInvalidDirection;
 
     do
     {
@@ -379,7 +391,7 @@ Direction Staff::HandymanDirectionToNearestLitter() const
             continue;
         if (tileElement->GetType() == TileElementType::Entrance || tileElement->GetType() == TileElementType::Track)
         {
-            return INVALID_DIRECTION;
+            return kInvalidDirection;
         }
     } while (!(tileElement++)->IsLastForTile());
 
@@ -396,18 +408,18 @@ uint8_t Staff::HandymanDirectionToUncutGrass(uint8_t valid_directions) const
     {
         auto surfaceElement = MapGetSurfaceElementAt(NextLoc);
         if (surfaceElement == nullptr)
-            return INVALID_DIRECTION;
+            return kInvalidDirection;
 
         if (NextLoc.z != surfaceElement->GetBaseZ())
-            return INVALID_DIRECTION;
+            return kInvalidDirection;
 
         if (GetNextIsSloped())
         {
             if (surfaceElement->GetSlope() != kPathSlopeToLandSlope[GetNextDirection()])
-                return INVALID_DIRECTION;
+                return kInvalidDirection;
         }
         else if (surfaceElement->GetSlope() != kTileSlopeFlat)
-            return INVALID_DIRECTION;
+            return kInvalidDirection;
     }
 
     uint8_t chosenDirection = ScenarioRand() & 0x3;
@@ -437,7 +449,7 @@ uint8_t Staff::HandymanDirectionToUncutGrass(uint8_t valid_directions) const
             }
         }
     }
-    return INVALID_DIRECTION;
+    return kInvalidDirection;
 }
 
 /**
@@ -475,21 +487,21 @@ bool Staff::DoHandymanPathFinding()
 {
     StaffMowingTimeout++;
 
-    Direction litterDirection = INVALID_DIRECTION;
+    Direction litterDirection = kInvalidDirection;
     uint8_t validDirections = GetValidPatrolDirections(NextLoc);
 
-    if ((StaffOrders & STAFF_ORDERS_SWEEPING) && ((GetGameState().CurrentTicks + Id.ToUnderlying()) & 0xFFF) > 110)
+    if ((StaffOrders & STAFF_ORDERS_SWEEPING) && ((getGameState().currentTicks + Id.ToUnderlying()) & 0xFFF) > 110)
     {
         litterDirection = HandymanDirectionToNearestLitter();
     }
 
-    Direction newDirection = INVALID_DIRECTION;
-    if (litterDirection == INVALID_DIRECTION && (StaffOrders & STAFF_ORDERS_MOWING) && StaffMowingTimeout >= 12)
+    Direction newDirection = kInvalidDirection;
+    if (litterDirection == kInvalidDirection && (StaffOrders & STAFF_ORDERS_MOWING) && StaffMowingTimeout >= 12)
     {
         newDirection = HandymanDirectionToUncutGrass(validDirections);
     }
 
-    if (newDirection == INVALID_DIRECTION)
+    if (newDirection == kInvalidDirection)
     {
         if (GetNextIsSurface())
         {
@@ -510,7 +522,7 @@ bool Staff::DoHandymanPathFinding()
             else
             {
                 bool chooseRandom = true;
-                if (litterDirection != INVALID_DIRECTION && pathDirections & (1 << litterDirection))
+                if (litterDirection != kInvalidDirection && pathDirections & (1 << litterDirection))
                 {
                     /// Check whether path is a queue path and connected to a ride
                     bool connectedQueue = (pathElement->IsQueue() && !pathElement->GetRideIndex().IsNull());
@@ -612,10 +624,10 @@ Direction Staff::MechanicDirectionSurface() const
     auto ride = GetRide(CurrentRide);
     if (ride != nullptr && (State == PeepState::Answering || State == PeepState::HeadingToInspection) && (ScenarioRand() & 1))
     {
-        auto location = ride->GetStation(CurrentRideStation).Exit;
+        auto location = ride->getStation(CurrentRideStation).Exit;
         if (location.IsNull())
         {
-            location = ride->GetStation(CurrentRideStation).Entrance;
+            location = ride->getStation(CurrentRideStation).Entrance;
         }
 
         direction = DirectionFromTo(CoordsXY(x, y), location.ToCoordsXY());
@@ -693,10 +705,10 @@ Direction Staff::MechanicDirectionPath(uint8_t validDirections, PathElement* pat
     {
         /* Find location of the exit for the target ride station
          * or if the ride has no exit, the entrance. */
-        TileCoordsXYZD location = ride->GetStation(CurrentRideStation).Exit;
+        TileCoordsXYZD location = ride->getStation(CurrentRideStation).Exit;
         if (location.IsNull())
         {
-            location = ride->GetStation(CurrentRideStation).Entrance;
+            location = ride->getStation(CurrentRideStation).Entrance;
 
             // If no entrance is present either. This is an incorrect state.
             if (location.IsNull())
@@ -708,7 +720,7 @@ Direction Staff::MechanicDirectionPath(uint8_t validDirections, PathElement* pat
         const auto goalPos = TileCoordsXYZ{ location };
         Direction pathfindDirection = PathFinding::ChooseDirection(
             TileCoordsXYZ{ NextLoc }, goalPos, *this, false, RideId::GetNull());
-        if (pathfindDirection == INVALID_DIRECTION)
+        if (pathfindDirection == kInvalidDirection)
         {
             /* Heuristic search failed for all directions.
              * Reset the PathfindGoal - this means that the PathfindHistory
@@ -732,7 +744,7 @@ Direction Staff::MechanicDirectionPath(uint8_t validDirections, PathElement* pat
 bool Staff::DoMechanicPathFinding()
 {
     uint8_t validDirections = GetValidPatrolDirections(NextLoc);
-    Direction newDirection = INVALID_DIRECTION;
+    Direction newDirection = kInvalidDirection;
     if (GetNextIsSurface())
     {
         newDirection = MechanicDirectionSurface();
@@ -813,7 +825,7 @@ bool Staff::DoMiscPathFinding()
 {
     uint8_t validDirections = GetValidPatrolDirections(NextLoc);
 
-    Direction newDirection = INVALID_DIRECTION;
+    Direction newDirection = kInvalidDirection;
     if (GetNextIsSurface())
     {
         newDirection = DirectionSurface(ScenarioRand() & 3);
@@ -866,32 +878,42 @@ bool Staff::IsMechanicHeadingToFixRideBlockingPath()
  */
 void Staff::EntertainerUpdateNearbyPeeps() const
 {
-    for (auto guest : EntityList<Guest>())
+    // Iterate over tiles within a 3-tile radius (96 units)
+    constexpr auto kTileRadius = 3;
+    constexpr auto kLookupRadius = kCoordsXYStep * kTileRadius;
+
+    for (int32_t tileX = x - kLookupRadius; tileX <= x + kLookupRadius; tileX += kCoordsXYStep)
     {
-        if (guest->x == kLocationNull)
-            continue;
-
-        int16_t z_dist = abs(z - guest->z);
-        if (z_dist > 48)
-            continue;
-
-        int16_t x_dist = abs(x - guest->x);
-        int16_t y_dist = abs(y - guest->y);
-
-        if (x_dist > 96)
-            continue;
-
-        if (y_dist > 96)
-            continue;
-
-        if (guest->State == PeepState::Walking)
+        for (int32_t tileY = y - kLookupRadius; tileY <= y + kLookupRadius; tileY += kCoordsXYStep)
         {
-            guest->HappinessTarget = std::min(guest->HappinessTarget + 4, kPeepMaxHappiness);
-        }
-        else if (guest->State == PeepState::Queuing)
-        {
-            guest->TimeInQueue = std::max(0, guest->TimeInQueue - 200);
-            guest->HappinessTarget = std::min(guest->HappinessTarget + 3, kPeepMaxHappiness);
+            for (auto* guest : EntityTileList<Guest>({ tileX, tileY }))
+            {
+                if (guest->x == kLocationNull)
+                    continue;
+
+                int16_t z_dist = std::abs(z - guest->z);
+                if (z_dist > kTileRadius / 2)
+                    continue;
+
+                int16_t x_dist = std::abs(x - guest->x);
+                int16_t y_dist = std::abs(y - guest->y);
+
+                if (x_dist > kLookupRadius)
+                    continue;
+
+                if (y_dist > kLookupRadius)
+                    continue;
+
+                if (guest->State == PeepState::Walking)
+                {
+                    guest->HappinessTarget = std::min(guest->HappinessTarget + 4, kPeepMaxHappiness);
+                }
+                else if (guest->State == PeepState::Queuing)
+                {
+                    guest->TimeInQueue = std::max(0, guest->TimeInQueue - 200);
+                    guest->HappinessTarget = std::min(guest->HappinessTarget + 3, kPeepMaxHappiness);
+                }
+            }
         }
     }
 }
@@ -950,15 +972,15 @@ int32_t Staff::GetHireDate() const
 
 colour_t StaffGetColour(StaffType staffType)
 {
-    const auto& gameState = GetGameState();
+    const auto& park = getGameState().park;
     switch (staffType)
     {
         case StaffType::Handyman:
-            return gameState.StaffHandymanColour;
+            return park.staffHandymanColour;
         case StaffType::Mechanic:
-            return gameState.StaffMechanicColour;
+            return park.staffMechanicColour;
         case StaffType::Security:
-            return gameState.StaffSecurityColour;
+            return park.staffSecurityColour;
         case StaffType::Entertainer:
             return 0;
         default:
@@ -969,17 +991,17 @@ colour_t StaffGetColour(StaffType staffType)
 
 GameActions::Result StaffSetColour(StaffType staffType, colour_t value)
 {
-    auto& gameState = GetGameState();
+    auto& park = getGameState().park;
     switch (staffType)
     {
         case StaffType::Handyman:
-            gameState.StaffHandymanColour = value;
+            park.staffHandymanColour = value;
             break;
         case StaffType::Mechanic:
-            gameState.StaffMechanicColour = value;
+            park.staffMechanicColour = value;
             break;
         case StaffType::Security:
-            gameState.StaffSecurityColour = value;
+            park.staffSecurityColour = value;
             break;
         default:
             return GameActions::Result(
@@ -1053,8 +1075,7 @@ void Staff::UpdateWatering()
         if (!CheckForPath())
             return;
 
-        uint8_t pathingResult;
-        PerformNextAction(pathingResult);
+        const auto [pathingResult, _] = PerformNextAction();
         if (!(pathingResult & PATHING_DESTINATION_REACHED))
             return;
 
@@ -1117,8 +1138,7 @@ void Staff::UpdateEmptyingBin()
         if (!CheckForPath())
             return;
 
-        uint8_t pathingResult;
-        PerformNextAction(pathingResult);
+        const auto [pathingResult, _] = PerformNextAction();
         if (!(pathingResult & PATHING_DESTINATION_REACHED))
             return;
 
@@ -1234,14 +1254,14 @@ void Staff::UpdateHeadingToInspect()
         return;
     }
 
-    if (ride->GetStation(CurrentRideStation).Exit.IsNull())
+    if (ride->getStation(CurrentRideStation).Exit.IsNull())
     {
-        ride->lifecycle_flags &= ~RIDE_LIFECYCLE_DUE_INSPECTION;
+        ride->lifecycleFlags &= ~RIDE_LIFECYCLE_DUE_INSPECTION;
         SetState(PeepState::Falling);
         return;
     }
 
-    if (ride->mechanic_status != RIDE_MECHANIC_STATUS_HEADING || !(ride->lifecycle_flags & RIDE_LIFECYCLE_DUE_INSPECTION))
+    if (ride->mechanicStatus != RIDE_MECHANIC_STATUS_HEADING || !(ride->lifecycleFlags & RIDE_LIFECYCLE_DUE_INSPECTION))
     {
         SetState(PeepState::Falling);
         return;
@@ -1259,9 +1279,9 @@ void Staff::UpdateHeadingToInspect()
         MechanicTimeSinceCall++;
         if (MechanicTimeSinceCall > 2500)
         {
-            if (ride->lifecycle_flags & RIDE_LIFECYCLE_DUE_INSPECTION && ride->mechanic_status == RIDE_MECHANIC_STATUS_HEADING)
+            if (ride->lifecycleFlags & RIDE_LIFECYCLE_DUE_INSPECTION && ride->mechanicStatus == RIDE_MECHANIC_STATUS_HEADING)
             {
-                ride->mechanic_status = RIDE_MECHANIC_STATUS_CALLING;
+                ride->mechanicStatus = RIDE_MECHANIC_STATUS_CALLING;
             }
             SetState(PeepState::Falling);
             return;
@@ -1273,10 +1293,7 @@ void Staff::UpdateHeadingToInspect()
         if (ShouldWaitForLevelCrossing() && !IsMechanicHeadingToFixRideBlockingPath())
             return;
 
-        uint8_t pathingResult;
-        TileElement* rideEntranceExitElement;
-        PerformNextAction(pathingResult, rideEntranceExitElement);
-
+        const auto [pathingResult, rideEntranceExitElement] = PerformNextAction();
         if (!(pathingResult & PATHING_RIDE_EXIT) && !(pathingResult & PATHING_RIDE_ENTRANCE))
         {
             return;
@@ -1291,7 +1308,7 @@ void Staff::UpdateHeadingToInspect()
 
         if (pathingResult & PATHING_RIDE_ENTRANCE)
         {
-            if (!ride->GetStation(exitIndex).Exit.IsNull())
+            if (!ride->getStation(exitIndex).Exit.IsNull())
             {
                 return;
             }
@@ -1311,10 +1328,10 @@ void Staff::UpdateHeadingToInspect()
     int16_t delta_y = abs(GetLocation().y - GetDestination().y);
     if (auto loc = UpdateAction(); loc.has_value())
     {
-        auto newZ = ride->GetStation(CurrentRideStation).GetBaseZ();
+        auto newZ = ride->getStation(CurrentRideStation).GetBaseZ();
         if (delta_y < 20)
         {
-            newZ += ride->GetRideTypeDescriptor().Heights.PlatformHeight;
+            newZ += ride->getRideTypeDescriptor().Heights.PlatformHeight;
         }
 
         MoveTo({ loc.value(), newZ });
@@ -1332,7 +1349,7 @@ void Staff::UpdateHeadingToInspect()
 void Staff::UpdateAnswering()
 {
     auto ride = GetRide(CurrentRide);
-    if (ride == nullptr || ride->mechanic_status != RIDE_MECHANIC_STATUS_HEADING)
+    if (ride == nullptr || ride->mechanicStatus != RIDE_MECHANIC_STATUS_HEADING)
     {
         SetState(PeepState::Falling);
         return;
@@ -1369,8 +1386,8 @@ void Staff::UpdateAnswering()
         MechanicTimeSinceCall++;
         if (MechanicTimeSinceCall > 2500)
         {
-            ride->mechanic_status = RIDE_MECHANIC_STATUS_CALLING;
-            ride->window_invalidate_flags |= RIDE_INVALIDATE_RIDE_MAINTENANCE;
+            ride->mechanicStatus = RIDE_MECHANIC_STATUS_CALLING;
+            ride->windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_MAINTENANCE;
             SetState(PeepState::Falling);
             return;
         }
@@ -1381,10 +1398,7 @@ void Staff::UpdateAnswering()
         if (ShouldWaitForLevelCrossing() && !IsMechanicHeadingToFixRideBlockingPath())
             return;
 
-        uint8_t pathingResult;
-        TileElement* rideEntranceExitElement;
-        PerformNextAction(pathingResult, rideEntranceExitElement);
-
+        const auto [pathingResult, rideEntranceExitElement] = PerformNextAction();
         if (!(pathingResult & PATHING_RIDE_EXIT) && !(pathingResult & PATHING_RIDE_ENTRANCE))
         {
             return;
@@ -1399,7 +1413,7 @@ void Staff::UpdateAnswering()
 
         if (pathingResult & PATHING_RIDE_ENTRANCE)
         {
-            if (!ride->GetStation(exitIndex).Exit.IsNull())
+            if (!ride->getStation(exitIndex).Exit.IsNull())
             {
                 return;
             }
@@ -1421,10 +1435,10 @@ void Staff::UpdateAnswering()
     int16_t delta_y = abs(y - GetDestination().y);
     if (auto loc = UpdateAction(); loc.has_value())
     {
-        auto newZ = ride->GetStation(CurrentRideStation).GetBaseZ();
+        auto newZ = ride->getStation(CurrentRideStation).GetBaseZ();
         if (delta_y < 20)
         {
-            newZ += ride->GetRideTypeDescriptor().Heights.PlatformHeight;
+            newZ += ride->getRideTypeDescriptor().Heights.PlatformHeight;
         }
 
         MoveTo({ loc.value(), newZ });
@@ -1633,14 +1647,58 @@ bool Staff::UpdatePatrollingFindSweeping()
     return false;
 }
 
+bool Staff::SecurityGuardPathIsCrowded() const
+{
+    // Iterate over tiles within a 3-tile radius (96 units)
+    constexpr auto kTileRadius = 3;
+    constexpr auto kLookupRadius = kCoordsXYStep * kTileRadius;
+    constexpr auto kSecurityPathCrowdedThreshold = 20;
+
+    int16_t guestCount = 0;
+
+    for (int32_t tileX = x - kLookupRadius; tileX <= x + kLookupRadius; tileX += kCoordsXYStep)
+    {
+        for (int32_t tileY = y - kLookupRadius; tileY <= y + kLookupRadius; tileY += kCoordsXYStep)
+        {
+            for (auto* guest : EntityTileList<Guest>({ tileX, tileY }))
+            {
+                if (guest->x == kLocationNull)
+                    continue;
+
+                int16_t zDist = std::abs(z - guest->z);
+                if (zDist > kTileRadius / 2)
+                    continue;
+
+                int16_t xDist = std::abs(x - guest->x);
+                if (xDist > kLookupRadius)
+                    continue;
+
+                int16_t yDist = std::abs(y - guest->y);
+                if (yDist > kLookupRadius)
+                    continue;
+
+                if (!guest->IsActionWalking())
+                    continue;
+
+                guestCount++;
+                if (guestCount >= kSecurityPathCrowdedThreshold)
+                    return true;
+            }
+        }
+    }
+
+    return false;
+}
+
 void Staff::Tick128UpdateStaff()
 {
     if (AssignedStaffType != StaffType::Security)
         return;
 
-    PeepAnimationGroup newAnimationGroup = PeepAnimationGroup::Alternate;
-    if (State != PeepState::Patrolling)
-        newAnimationGroup = PeepAnimationGroup::Normal;
+    // Alternate between walking animations based on crowd size
+    auto newAnimationGroup = PeepAnimationGroup::Normal;
+    if (State == PeepState::Patrolling && SecurityGuardPathIsCrowded())
+        newAnimationGroup = PeepAnimationGroup::Alternate;
 
     if (AnimationGroup == newAnimationGroup)
         return;
@@ -1654,6 +1712,7 @@ void Staff::Tick128UpdateStaff()
     auto& objManager = GetContext()->GetObjectManager();
     auto* animObj = objManager.GetLoadedObject<PeepAnimationsObject>(AnimationObjectIndex);
 
+    // NB: security staff have two animations groups: one regular, and one slow-walking
     PeepFlags &= ~PEEP_FLAGS_SLOW_WALK;
     if (animObj->IsSlowWalking(newAnimationGroup))
     {
@@ -1669,41 +1728,95 @@ bool Staff::IsMechanic() const
     return AssignedStaffType == StaffType::Mechanic;
 }
 
-void Staff::UpdateStaff(uint32_t stepsToTake)
+bool Staff::isEntertainer() const
 {
-    switch (State)
+    return AssignedStaffType == StaffType::Entertainer;
+}
+
+void Staff::Update()
+{
+    if (PeepFlags & PEEP_FLAGS_POSITION_FROZEN)
     {
-        case PeepState::Patrolling:
-            UpdatePatrolling();
-            break;
-        case PeepState::Mowing:
-            UpdateMowing();
-            break;
-        case PeepState::Sweeping:
-            UpdateSweeping();
-            break;
-        case PeepState::Answering:
-            UpdateAnswering();
-            break;
-        case PeepState::Fixing:
-            UpdateFixing(stepsToTake);
-            break;
-        case PeepState::Inspecting:
-            UpdateFixing(stepsToTake);
-            break;
-        case PeepState::EmptyingBin:
-            UpdateEmptyingBin();
-            break;
-        case PeepState::Watering:
-            UpdateWatering();
-            break;
-        case PeepState::HeadingToInspection:
-            UpdateHeadingToInspect();
-            break;
-        default:
-            // TODO reset to default state
-            assert(false);
-            break;
+        if (!(PeepFlags & PEEP_FLAGS_ANIMATION_FROZEN))
+        {
+            // This is circumventing other logic, so only update every few ticks
+            if ((getGameState().currentTicks & 3) == 0)
+            {
+                if (IsActionWalking())
+                    UpdateWalkingAnimation();
+                else
+                    UpdateActionAnimation();
+                Invalidate();
+            }
+        }
+        return;
+    }
+    else if (PeepFlags & PEEP_FLAGS_ANIMATION_FROZEN)
+    {
+        // Animation is frozen while position is not. This allows a peep to walk
+        // around without its sprite being updated, which looks very glitchy.
+        // We'll just remove the flag and continue as normal, in this case.
+        PeepFlags &= ~PEEP_FLAGS_ANIMATION_FROZEN;
+    }
+
+    // Walking speed logic
+    const auto stepsToTake = GetStepsToTake();
+    const auto carryCheck = StepProgress + stepsToTake;
+    StepProgress = carryCheck;
+
+    if (carryCheck <= 255)
+    {
+        // No-op: Keep replay working for now, can be eliminate with a replay update.
+    }
+    else
+    {
+        // Loc68FD2F
+        switch (State)
+        {
+            case PeepState::Falling:
+                UpdateFalling();
+                break;
+            case PeepState::One:
+                Update1();
+                break;
+            case PeepState::OnRide:
+                // No action
+                break;
+            case PeepState::Picked:
+                UpdatePicked();
+                break;
+            case PeepState::Patrolling:
+                UpdatePatrolling();
+                break;
+            case PeepState::Mowing:
+                UpdateMowing();
+                break;
+            case PeepState::Sweeping:
+                UpdateSweeping();
+                break;
+            case PeepState::Answering:
+                UpdateAnswering();
+                break;
+            case PeepState::Fixing:
+                UpdateFixing(stepsToTake);
+                break;
+            case PeepState::Inspecting:
+                UpdateFixing(stepsToTake);
+                break;
+            case PeepState::EmptyingBin:
+                UpdateEmptyingBin();
+                break;
+            case PeepState::Watering:
+                UpdateWatering();
+                break;
+            case PeepState::HeadingToInspection:
+                UpdateHeadingToInspect();
+                break;
+            default:
+                // TODO reset to default state
+                assert(false);
+                break;
+        }
     }
 }
 
@@ -1719,8 +1832,7 @@ void Staff::UpdatePatrolling()
     if (ShouldWaitForLevelCrossing() && !IsMechanicHeadingToFixRideBlockingPath())
         return;
 
-    uint8_t pathingResult;
-    PerformNextAction(pathingResult);
+    const auto [pathingResult, _] = PerformNextAction();
     if (!(pathingResult & PATHING_DESTINATION_REACHED))
         return;
 
@@ -1776,7 +1888,7 @@ enum
 
 /**
  * FixingSubstatesForBreakdown[] defines the applicable peep sub_states for
- * mechanics fixing a ride. The array is indexed by breakdown_reason:
+ * mechanics fixing a ride. The array is indexed by breakdownReason:
  * - indexes 0-7 are the 8 breakdown reasons (see BREAKDOWN_* in Ride.h)
  *   when fixing a broken down ride;
  * - index 8 is for inspecting a ride.
@@ -1873,7 +1985,7 @@ void Staff::UpdateFixing(int32_t steps)
     bool firstRun = true;
 
     if ((State == PeepState::Inspecting)
-        && (ride->lifecycle_flags & (RIDE_LIFECYCLE_BREAKDOWN_PENDING | RIDE_LIFECYCLE_BROKEN_DOWN)))
+        && (ride->lifecycleFlags & (RIDE_LIFECYCLE_BREAKDOWN_PENDING | RIDE_LIFECYCLE_BROKEN_DOWN)))
     {
         // Ride has broken down since Mechanic was called to inspect it.
         // Mechanic identifies the breakdown and switches to fixing it.
@@ -1953,7 +2065,7 @@ void Staff::UpdateFixing(int32_t steps)
 
         if (State != PeepState::Inspecting)
         {
-            sub_state_sequence_mask = FixingSubstatesForBreakdown[ride->breakdown_reason_pending];
+            sub_state_sequence_mask = FixingSubstatesForBreakdown[ride->breakdownReasonPending];
         }
 
         do
@@ -1971,8 +2083,8 @@ void Staff::UpdateFixing(int32_t steps)
  */
 bool Staff::UpdateFixingEnterStation(Ride& ride) const
 {
-    ride.mechanic_status = RIDE_MECHANIC_STATUS_FIXING;
-    ride.window_invalidate_flags |= RIDE_INVALIDATE_RIDE_MAINTENANCE;
+    ride.mechanicStatus = RIDE_MECHANIC_STATUS_FIXING;
+    ride.windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_MAINTENANCE;
 
     return true;
 }
@@ -2005,7 +2117,7 @@ bool Staff::UpdateFixingMoveToBrokenDownVehicle(bool firstRun, const Ride& ride)
                 break;
             }
 
-            vehicle = GetEntity<Vehicle>(vehicle->prev_vehicle_on_ride);
+            vehicle = getGameState().entities.GetEntity<Vehicle>(vehicle->prev_vehicle_on_ride);
             if (vehicle == nullptr)
             {
                 return true;
@@ -2131,13 +2243,13 @@ bool Staff::UpdateFixingMoveToStationEnd(bool firstRun, const Ride& ride)
 {
     if (!firstRun)
     {
-        if (ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation)
-            || !ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
+        if (ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation)
+            || !ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
         {
             return true;
         }
 
-        auto stationPos = ride.GetStation(CurrentRideStation).GetStart();
+        auto stationPos = ride.getStation(CurrentRideStation).GetStart();
         if (stationPos.IsNull())
         {
             return true;
@@ -2218,13 +2330,13 @@ bool Staff::UpdateFixingMoveToStationStart(bool firstRun, const Ride& ride)
 {
     if (!firstRun)
     {
-        if (ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation)
-            || !ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
+        if (ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation)
+            || !ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
         {
             return true;
         }
 
-        auto stationPosition = ride.GetStation(CurrentRideStation).GetStart();
+        auto stationPosition = ride.getStation(CurrentRideStation).GetStart();
         if (stationPosition.IsNull())
         {
             return true;
@@ -2295,8 +2407,8 @@ bool Staff::UpdateFixingFixStationStart(bool firstRun, const Ride& ride)
 {
     if (!firstRun)
     {
-        if (ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation)
-            || !ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
+        if (ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasSinglePieceStation)
+            || !ride.getRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
         {
             return true;
         }
@@ -2348,14 +2460,14 @@ bool Staff::UpdateFixingFixStationBrakes(bool firstRun, Ride& ride)
 
     if (AnimationFrameNum == 0x28)
     {
-        ride.mechanic_status = RIDE_MECHANIC_STATUS_HAS_FIXED_STATION_BRAKES;
-        ride.window_invalidate_flags |= RIDE_INVALIDATE_RIDE_MAINTENANCE;
+        ride.mechanicStatus = RIDE_MECHANIC_STATUS_HAS_FIXED_STATION_BRAKES;
+        ride.windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_MAINTENANCE;
     }
 
     if (AnimationFrameNum == 0x13 || AnimationFrameNum == 0x19 || AnimationFrameNum == 0x1F || AnimationFrameNum == 0x25
         || AnimationFrameNum == 0x2B)
     {
-        OpenRCT2::Audio::Play3D(OpenRCT2::Audio::SoundId::MechanicFix, GetLocation());
+        OpenRCT2::Audio::Play3D(OpenRCT2::Audio::SoundId::mechanicFix, GetLocation());
     }
 
     return false;
@@ -2370,10 +2482,10 @@ bool Staff::UpdateFixingMoveToStationExit(bool firstRun, const Ride& ride)
 {
     if (!firstRun)
     {
-        auto stationPosition = ride.GetStation(CurrentRideStation).Exit.ToCoordsXY();
+        auto stationPosition = ride.getStation(CurrentRideStation).Exit.ToCoordsXY();
         if (stationPosition.IsNull())
         {
-            stationPosition = ride.GetStation(CurrentRideStation).Entrance.ToCoordsXY();
+            stationPosition = ride.getStation(CurrentRideStation).Entrance.ToCoordsXY();
 
             if (stationPosition.IsNull())
             {
@@ -2414,7 +2526,7 @@ bool Staff::UpdateFixingFinishFixOrInspect(bool firstRun, int32_t steps, Ride& r
 
             StaffRidesInspected = AddClamp(StaffRidesInspected, 1u);
             WindowInvalidateFlags |= RIDE_INVALIDATE_RIDE_INCOME | RIDE_INVALIDATE_RIDE_LIST;
-            ride.mechanic_status = RIDE_MECHANIC_STATUS_UNDEFINED;
+            ride.mechanicStatus = RIDE_MECHANIC_STATUS_UNDEFINED;
             return true;
         }
 
@@ -2437,7 +2549,7 @@ bool Staff::UpdateFixingFinishFixOrInspect(bool firstRun, int32_t steps, Ride& r
     }
 
     RideFixBreakdown(ride, steps);
-    ride.mechanic_status = RIDE_MECHANIC_STATUS_UNDEFINED;
+    ride.mechanicStatus = RIDE_MECHANIC_STATUS_UNDEFINED;
     return true;
 }
 
@@ -2450,10 +2562,10 @@ bool Staff::UpdateFixingLeaveByEntranceExit(bool firstRun, const Ride& ride)
 {
     if (!firstRun)
     {
-        auto exitPosition = ride.GetStation(CurrentRideStation).Exit.ToCoordsXY();
+        auto exitPosition = ride.getStation(CurrentRideStation).Exit.ToCoordsXY();
         if (exitPosition.IsNull())
         {
-            exitPosition = ride.GetStation(CurrentRideStation).Entrance.ToCoordsXY();
+            exitPosition = ride.getStation(CurrentRideStation).Entrance.ToCoordsXY();
 
             if (exitPosition.IsNull())
             {
@@ -2474,10 +2586,10 @@ bool Staff::UpdateFixingLeaveByEntranceExit(bool firstRun, const Ride& ride)
     int16_t xy_distance;
     if (auto loc = UpdateAction(xy_distance); loc.has_value())
     {
-        auto stationHeight = ride.GetStation(CurrentRideStation).GetBaseZ();
+        auto stationHeight = ride.getStation(CurrentRideStation).GetBaseZ();
         if (xy_distance >= 16)
         {
-            stationHeight += ride.GetRideTypeDescriptor().Heights.PlatformHeight;
+            stationHeight += ride.getRideTypeDescriptor().Heights.PlatformHeight;
         }
 
         MoveTo({ loc.value(), stationHeight });
@@ -2495,11 +2607,10 @@ void Staff::UpdateRideInspected(RideId rideIndex)
     auto ride = GetRide(rideIndex);
     if (ride != nullptr)
     {
-        ride->lifecycle_flags &= ~RIDE_LIFECYCLE_DUE_INSPECTION;
-        ride->reliability += ((100 - ride->reliability_percentage) / 4) * (ScenarioRand() & 0xFF);
-        ride->last_inspection = 0;
-        ride->window_invalidate_flags |= RIDE_INVALIDATE_RIDE_MAINTENANCE | RIDE_INVALIDATE_RIDE_MAIN
-            | RIDE_INVALIDATE_RIDE_LIST;
+        ride->lifecycleFlags &= ~RIDE_LIFECYCLE_DUE_INSPECTION;
+        ride->reliability += ((100 - ride->reliabilityPercentage) / 4) * (ScenarioRand() & 0xFF);
+        ride->lastInspection = 0;
+        ride->windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_MAINTENANCE | RIDE_INVALIDATE_RIDE_MAIN | RIDE_INVALIDATE_RIDE_LIST;
     }
 }
 
