@@ -73,8 +73,8 @@ const StringId kResearchFundingLevelNames[] = {
  */
 void ResearchResetItems(GameState_t& gameState)
 {
-    gameState.ResearchItemsUninvented.clear();
-    gameState.ResearchItemsInvented.clear();
+    gameState.researchItemsUninvented.clear();
+    gameState.researchItemsInvented.clear();
 }
 
 /**
@@ -83,15 +83,15 @@ void ResearchResetItems(GameState_t& gameState)
  */
 void ResearchUpdateUncompletedTypes()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     int32_t uncompletedResearchTypes = 0;
 
-    for (auto const& researchItem : gameState.ResearchItemsUninvented)
+    for (auto const& researchItem : gameState.researchItemsUninvented)
     {
         uncompletedResearchTypes |= EnumToFlag(researchItem.category);
     }
 
-    gameState.ResearchUncompletedCategories = uncompletedResearchTypes;
+    gameState.researchUncompletedCategories = uncompletedResearchTypes;
 }
 
 /**
@@ -100,19 +100,19 @@ void ResearchUpdateUncompletedTypes()
  */
 static void ResearchCalculateExpectedDate()
 {
-    auto& gameState = GetGameState();
-    if (gameState.ResearchProgressStage == RESEARCH_STAGE_INITIAL_RESEARCH
-        || gameState.ResearchFundingLevel == RESEARCH_FUNDING_NONE)
+    auto& gameState = getGameState();
+    if (gameState.researchProgressStage == RESEARCH_STAGE_INITIAL_RESEARCH
+        || gameState.researchFundingLevel == RESEARCH_FUNDING_NONE)
     {
-        gameState.ResearchExpectedDay = 255;
+        gameState.researchExpectedDay = 255;
     }
     else
     {
         auto& date = GetDate();
 
-        int32_t progressRemaining = gameState.ResearchProgressStage == RESEARCH_STAGE_COMPLETING_DESIGN ? 0x10000 : 0x20000;
-        progressRemaining -= gameState.ResearchProgress;
-        int32_t daysRemaining = (progressRemaining / _researchRate[gameState.ResearchFundingLevel]) * 128;
+        int32_t progressRemaining = gameState.researchProgressStage == RESEARCH_STAGE_COMPLETING_DESIGN ? 0x10000 : 0x20000;
+        progressRemaining -= gameState.researchProgress;
+        int32_t daysRemaining = (progressRemaining / _researchRate[gameState.researchFundingLevel]) * 128;
 
         int32_t expectedDay = date.GetMonthTicks() + (daysRemaining & 0xFFFF);
         int32_t dayQuotient = expectedDay / 0x10000;
@@ -121,27 +121,28 @@ static void ResearchCalculateExpectedDate()
         int32_t expectedMonth = DateGetMonth(date.GetMonthsElapsed() + dayQuotient + (daysRemaining >> 16));
         expectedDay = (dayRemainder * Date::GetDaysInMonth(expectedMonth)) >> 16;
 
-        gameState.ResearchExpectedDay = expectedDay;
-        gameState.ResearchExpectedMonth = expectedMonth;
+        gameState.researchExpectedDay = expectedDay;
+        gameState.researchExpectedMonth = expectedMonth;
     }
 }
 
 static void ResearchInvalidateRelatedWindows()
 {
     auto* windowMgr = Ui::GetWindowManager();
-    windowMgr->InvalidateByClass(WindowClass::ConstructRide);
-    windowMgr->InvalidateByClass(WindowClass::Research);
+    windowMgr->InvalidateByClass(WindowClass::constructRide);
+    windowMgr->InvalidateByClass(WindowClass::research);
 }
 
 static void ResearchMarkAsFullyCompleted()
 {
-    auto& gameState = GetGameState();
-    gameState.ResearchProgress = 0;
-    gameState.ResearchProgressStage = RESEARCH_STAGE_FINISHED_ALL;
+    auto& gameState = getGameState();
+    gameState.researchProgress = 0;
+    gameState.researchProgressStage = RESEARCH_STAGE_FINISHED_ALL;
     ResearchInvalidateRelatedWindows();
+
     // Reset funding to 0 if no more rides.
-    auto gameAction = ParkSetResearchFundingAction(gameState.ResearchPriorities, 0);
-    GameActions::Execute(&gameAction);
+    auto gameAction = GameActions::ParkSetResearchFundingAction(gameState.researchPriorities, 0);
+    GameActions::Execute(&gameAction, gameState);
 }
 
 /**
@@ -150,8 +151,8 @@ static void ResearchMarkAsFullyCompleted()
  */
 static void ResearchNextDesign()
 {
-    auto& gameState = GetGameState();
-    if (gameState.ResearchItemsUninvented.empty())
+    auto& gameState = getGameState();
+    if (gameState.researchItemsUninvented.empty())
     {
         ResearchMarkAsFullyCompleted();
         return;
@@ -159,31 +160,31 @@ static void ResearchNextDesign()
 
     // Try to find a research item of a matching type, if none found, use any first item
     auto it = std::find_if(
-        gameState.ResearchItemsUninvented.begin(), gameState.ResearchItemsUninvented.end(),
-        [&gameState](const auto& e) { return (gameState.ResearchPriorities & EnumToFlag(e.category)) != 0; });
-    if (it == gameState.ResearchItemsUninvented.end())
+        gameState.researchItemsUninvented.begin(), gameState.researchItemsUninvented.end(),
+        [&gameState](const auto& e) { return (gameState.researchPriorities & EnumToFlag(e.category)) != 0; });
+    if (it == gameState.researchItemsUninvented.end())
     {
-        it = gameState.ResearchItemsUninvented.begin();
+        it = gameState.researchItemsUninvented.begin();
     }
 
-    gameState.ResearchNextItem = *it;
-    gameState.ResearchProgress = 0;
-    gameState.ResearchProgressStage = RESEARCH_STAGE_DESIGNING;
+    gameState.researchNextItem = *it;
+    gameState.researchProgress = 0;
+    gameState.researchProgressStage = RESEARCH_STAGE_DESIGNING;
 
     ResearchInvalidateRelatedWindows();
 }
 
 static void MarkResearchItemInvented(const ResearchItem& researchItem)
 {
-    auto& gameState = GetGameState();
-    gameState.ResearchItemsUninvented.erase(
-        std::remove(gameState.ResearchItemsUninvented.begin(), gameState.ResearchItemsUninvented.end(), researchItem),
-        gameState.ResearchItemsUninvented.end());
+    auto& gameState = getGameState();
+    gameState.researchItemsUninvented.erase(
+        std::remove(gameState.researchItemsUninvented.begin(), gameState.researchItemsUninvented.end(), researchItem),
+        gameState.researchItemsUninvented.end());
 
-    if (std::find(gameState.ResearchItemsInvented.begin(), gameState.ResearchItemsInvented.end(), researchItem)
-        == gameState.ResearchItemsInvented.end())
+    if (std::find(gameState.researchItemsInvented.begin(), gameState.researchItemsInvented.end(), researchItem)
+        == gameState.researchItemsInvented.end())
     {
-        gameState.ResearchItemsInvented.push_back(researchItem);
+        gameState.researchItemsInvented.push_back(researchItem);
     }
 }
 
@@ -193,8 +194,8 @@ static void MarkResearchItemInvented(const ResearchItem& researchItem)
  */
 void ResearchFinishItem(const ResearchItem& researchItem)
 {
-    auto& gameState = GetGameState();
-    gameState.ResearchLastItem = researchItem;
+    auto& gameState = getGameState();
+    gameState.researchLastItem = researchItem;
     ResearchInvalidateRelatedWindows();
 
     if (researchItem.type == Research::EntryType::Ride)
@@ -217,7 +218,7 @@ void ResearchFinishItem(const ResearchItem& researchItem)
             RideEntrySetInvented(rideEntryIndex);
 
             bool seenRideEntry[kMaxRideObjects]{};
-            for (auto const& researchItem3 : gameState.ResearchItemsUninvented)
+            for (auto const& researchItem3 : gameState.researchItemsUninvented)
             {
                 ObjectEntryIndex index = researchItem3.entryIndex;
                 seenRideEntry[index] = true;
@@ -271,7 +272,7 @@ void ResearchFinishItem(const ResearchItem& researchItem)
             {
                 if (Config::Get().notifications.RideResearched)
                 {
-                    News::AddItemToQueue(News::ItemType::Research, availabilityString, researchItem.rawValue, ft);
+                    News::AddItemToQueue(News::ItemType::research, availabilityString, researchItem.rawValue, ft);
                 }
             }
 
@@ -294,7 +295,7 @@ void ResearchFinishItem(const ResearchItem& researchItem)
                 if (Config::Get().notifications.RideResearched)
                 {
                     News::AddItemToQueue(
-                        News::ItemType::Research, STR_NEWS_ITEM_RESEARCH_NEW_SCENERY_SET_AVAILABLE, researchItem.rawValue, ft);
+                        News::ItemType::research, STR_NEWS_ITEM_RESEARCH_NEW_SCENERY_SET_AVAILABLE, researchItem.rawValue, ft);
                 }
             }
 
@@ -314,60 +315,59 @@ void ResearchUpdate()
 {
     PROFILED_FUNCTION();
 
-    int32_t editorScreenFlags, researchLevel, currentResearchProgress;
+    int32_t researchLevel, currentResearchProgress;
 
-    editorScreenFlags = SCREEN_FLAGS_SCENARIO_EDITOR | SCREEN_FLAGS_TRACK_DESIGNER | SCREEN_FLAGS_TRACK_MANAGER;
-    if (gScreenFlags & editorScreenFlags)
+    if (isInEditorMode())
     {
         return;
     }
 
-    auto& gameState = GetGameState();
-    if (gameState.CurrentTicks % 32 != 0)
+    auto& gameState = getGameState();
+    if (gameState.currentTicks % 32 != 0)
     {
         return;
     }
 
-    if ((gameState.Park.Flags & PARK_FLAGS_NO_MONEY) && gameState.ResearchFundingLevel == RESEARCH_FUNDING_NONE)
+    if ((gameState.park.flags & PARK_FLAGS_NO_MONEY) && gameState.researchFundingLevel == RESEARCH_FUNDING_NONE)
     {
         researchLevel = RESEARCH_FUNDING_NORMAL;
     }
     else
     {
-        researchLevel = gameState.ResearchFundingLevel;
+        researchLevel = gameState.researchFundingLevel;
     }
 
-    currentResearchProgress = gameState.ResearchProgress;
+    currentResearchProgress = gameState.researchProgress;
     currentResearchProgress += _researchRate[researchLevel];
     if (currentResearchProgress <= 0xFFFF)
     {
-        gameState.ResearchProgress = currentResearchProgress;
+        gameState.researchProgress = currentResearchProgress;
     }
     else
     {
-        switch (gameState.ResearchProgressStage)
+        switch (gameState.researchProgressStage)
         {
             case RESEARCH_STAGE_INITIAL_RESEARCH:
                 ResearchNextDesign();
                 ResearchCalculateExpectedDate();
                 break;
             case RESEARCH_STAGE_DESIGNING:
-                gameState.ResearchProgress = 0;
-                gameState.ResearchProgressStage = RESEARCH_STAGE_COMPLETING_DESIGN;
+                gameState.researchProgress = 0;
+                gameState.researchProgressStage = RESEARCH_STAGE_COMPLETING_DESIGN;
                 ResearchCalculateExpectedDate();
                 ResearchInvalidateRelatedWindows();
                 break;
             case RESEARCH_STAGE_COMPLETING_DESIGN:
-                MarkResearchItemInvented(*gameState.ResearchNextItem);
-                ResearchFinishItem(*gameState.ResearchNextItem);
-                gameState.ResearchProgress = 0;
-                gameState.ResearchProgressStage = RESEARCH_STAGE_INITIAL_RESEARCH;
+                MarkResearchItemInvented(*gameState.researchNextItem);
+                ResearchFinishItem(*gameState.researchNextItem);
+                gameState.researchProgress = 0;
+                gameState.researchProgressStage = RESEARCH_STAGE_INITIAL_RESEARCH;
                 ResearchCalculateExpectedDate();
                 ResearchUpdateUncompletedTypes();
                 ResearchInvalidateRelatedWindows();
                 break;
             case RESEARCH_STAGE_FINISHED_ALL:
-                gameState.ResearchFundingLevel = RESEARCH_FUNDING_NONE;
+                gameState.researchFundingLevel = RESEARCH_FUNDING_NONE;
                 break;
         }
     }
@@ -379,7 +379,7 @@ void ResearchUpdate()
  */
 void ResearchResetCurrentItem()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     SetEveryRideTypeNotInvented();
     SetEveryRideEntryNotInvented();
 
@@ -387,14 +387,14 @@ void ResearchResetCurrentItem()
     SetAllSceneryItemsInvented();
     SetAllSceneryGroupsNotInvented();
 
-    for (const auto& researchItem : gameState.ResearchItemsInvented)
+    for (const auto& researchItem : gameState.researchItemsInvented)
     {
         ResearchFinishItem(researchItem);
     }
 
-    gameState.ResearchLastItem = std::nullopt;
-    gameState.ResearchProgressStage = RESEARCH_STAGE_INITIAL_RESEARCH;
-    gameState.ResearchProgress = 0;
+    gameState.researchLastItem = std::nullopt;
+    gameState.researchProgressStage = RESEARCH_STAGE_INITIAL_RESEARCH;
+    gameState.researchProgress = 0;
 }
 
 /**
@@ -403,14 +403,14 @@ void ResearchResetCurrentItem()
  */
 static void ResearchInsertUnresearched(ResearchItem&& item)
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     // First check to make sure that entry is not already accounted for
     if (item.Exists())
     {
         return;
     }
 
-    gameState.ResearchItemsUninvented.push_back(std::move(item));
+    gameState.researchItemsUninvented.push_back(std::move(item));
 }
 
 /**
@@ -419,14 +419,14 @@ static void ResearchInsertUnresearched(ResearchItem&& item)
  */
 static void ResearchInsertResearched(ResearchItem&& item)
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     // First check to make sure that entry is not already accounted for
     if (item.Exists())
     {
         return;
     }
 
-    gameState.ResearchItemsInvented.push_back(std::move(item));
+    gameState.researchItemsInvented.push_back(std::move(item));
 }
 
 /**
@@ -435,13 +435,13 @@ static void ResearchInsertResearched(ResearchItem&& item)
  */
 void ResearchRemove(const ResearchItem& researchItem)
 {
-    auto& gameState = GetGameState();
-    gameState.ResearchItemsUninvented.erase(
-        std::remove(gameState.ResearchItemsUninvented.begin(), gameState.ResearchItemsUninvented.end(), researchItem),
-        gameState.ResearchItemsUninvented.end());
-    gameState.ResearchItemsInvented.erase(
-        std::remove(gameState.ResearchItemsInvented.begin(), gameState.ResearchItemsInvented.end(), researchItem),
-        gameState.ResearchItemsInvented.end());
+    auto& gameState = getGameState();
+    gameState.researchItemsUninvented.erase(
+        std::remove(gameState.researchItemsUninvented.begin(), gameState.researchItemsUninvented.end(), researchItem),
+        gameState.researchItemsUninvented.end());
+    gameState.researchItemsInvented.erase(
+        std::remove(gameState.researchItemsInvented.begin(), gameState.researchItemsInvented.end(), researchItem),
+        gameState.researchItemsInvented.end());
 }
 
 void ResearchInsert(ResearchItem&& item, bool researched)
@@ -462,7 +462,7 @@ void ResearchInsert(ResearchItem&& item, bool researched)
  */
 void ResearchPopulateListRandom()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     ResearchResetItems(gameState);
 
     // Rides
@@ -627,7 +627,7 @@ void ScenerySetNotInvented(const ScenerySelection& sceneryItem)
 
 bool SceneryGroupIsInvented(int32_t sgIndex)
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     const auto sgEntry = OpenRCT2::ObjectManager::GetObjectEntry<SceneryGroupEntry>(sgIndex);
     if (sgEntry == nullptr || sgEntry->SceneryEntries.empty())
     {
@@ -635,18 +635,18 @@ bool SceneryGroupIsInvented(int32_t sgIndex)
     }
 
     // All scenery is temporarily invented when in the scenario editor
-    if (gScreenFlags & SCREEN_FLAGS_EDITOR)
+    if (isInEditorMode())
     {
         return true;
     }
 
-    if (GetGameState().Cheats.ignoreResearchStatus)
+    if (getGameState().cheats.ignoreResearchStatus)
     {
         return true;
     }
 
     return std::none_of(
-        std::begin(gameState.ResearchItemsUninvented), std::end(gameState.ResearchItemsUninvented),
+        std::begin(gameState.researchItemsUninvented), std::end(gameState.researchItemsUninvented),
         [sgIndex](const ResearchItem& item) {
             return item.type == Research::EntryType::Scenery && item.entryIndex == sgIndex;
         });
@@ -751,12 +751,12 @@ StringId ResearchItem::GetName() const
  */
 void ResearchRemoveFlags()
 {
-    auto& gameState = GetGameState();
-    for (auto& researchItem : gameState.ResearchItemsUninvented)
+    auto& gameState = getGameState();
+    for (auto& researchItem : gameState.researchItemsUninvented)
     {
         researchItem.flags &= ~(RESEARCH_ENTRY_FLAG_RIDE_ALWAYS_RESEARCHED | RESEARCH_ENTRY_FLAG_SCENERY_SET_ALWAYS_RESEARCHED);
     }
-    for (auto& researchItem : gameState.ResearchItemsInvented)
+    for (auto& researchItem : gameState.researchItemsInvented)
     {
         researchItem.flags &= ~(RESEARCH_ENTRY_FLAG_RIDE_ALWAYS_RESEARCHED | RESEARCH_ENTRY_FLAG_SCENERY_SET_ALWAYS_RESEARCHED);
     }
@@ -809,18 +809,18 @@ static void ResearchMarkItemAsResearched(const ResearchItem& item)
 
 static void ResearchRebuildInventedTables()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     SetEveryRideTypeNotInvented();
     SetEveryRideEntryInvented();
     SetEveryRideEntryNotInvented();
     SetAllSceneryItemsNotInvented();
-    for (const auto& item : gameState.ResearchItemsInvented)
+    for (const auto& item : gameState.researchItemsInvented)
     {
         // Ignore item, if the research of it is in progress
-        if (gameState.ResearchProgressStage == RESEARCH_STAGE_DESIGNING
-            || gameState.ResearchProgressStage == RESEARCH_STAGE_COMPLETING_DESIGN)
+        if (gameState.researchProgressStage == RESEARCH_STAGE_DESIGNING
+            || gameState.researchProgressStage == RESEARCH_STAGE_COMPLETING_DESIGN)
         {
-            if (item == gameState.ResearchNextItem)
+            if (item == gameState.researchNextItem)
             {
                 continue;
             }
@@ -833,10 +833,10 @@ static void ResearchRebuildInventedTables()
 
 static void ResearchAddAllMissingItems(bool isResearched)
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     // Mark base ridetypes as seen if they exist in the invented research list.
     bool seenBaseEntry[kMaxRideObjects]{};
-    for (auto const& researchItem : gameState.ResearchItemsInvented)
+    for (auto const& researchItem : gameState.researchItemsInvented)
     {
         ObjectEntryIndex index = researchItem.baseRideType;
         seenBaseEntry[index] = true;
@@ -861,7 +861,7 @@ static void ResearchAddAllMissingItems(bool isResearched)
     }
 
     // Mark base ridetypes as seen if they exist in the uninvented research list.
-    for (auto const& researchItem : gameState.ResearchItemsUninvented)
+    for (auto const& researchItem : gameState.researchItemsUninvented)
     {
         ObjectEntryIndex index = researchItem.baseRideType;
         seenBaseEntry[index] = true;
@@ -902,14 +902,14 @@ static void ResearchAddAllMissingItems(bool isResearched)
 
 void ResearchFix()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     // Remove null entries from the research list
-    ResearchRemoveNullItems(gameState.ResearchItemsInvented);
-    ResearchRemoveNullItems(gameState.ResearchItemsUninvented);
+    ResearchRemoveNullItems(gameState.researchItemsInvented);
+    ResearchRemoveNullItems(gameState.researchItemsUninvented);
 
     // Add missing entries to the research list
     // If research is complete, mark all the missing items as available
-    ResearchAddAllMissingItems(gameState.ResearchProgressStage == RESEARCH_STAGE_FINISHED_ALL);
+    ResearchAddAllMissingItems(gameState.researchProgressStage == RESEARCH_STAGE_FINISHED_ALL);
 
     // Now rebuild all the tables that say whether a ride or scenery item is invented
     ResearchRebuildInventedTables();
@@ -918,20 +918,20 @@ void ResearchFix()
 
 void ResearchItemsMakeAllUnresearched()
 {
-    auto& gameState = GetGameState();
-    gameState.ResearchItemsUninvented.insert(
-        gameState.ResearchItemsUninvented.end(), std::make_move_iterator(gameState.ResearchItemsInvented.begin()),
-        std::make_move_iterator(gameState.ResearchItemsInvented.end()));
-    gameState.ResearchItemsInvented.clear();
+    auto& gameState = getGameState();
+    gameState.researchItemsUninvented.insert(
+        gameState.researchItemsUninvented.end(), std::make_move_iterator(gameState.researchItemsInvented.begin()),
+        std::make_move_iterator(gameState.researchItemsInvented.end()));
+    gameState.researchItemsInvented.clear();
 }
 
 void ResearchItemsMakeAllResearched()
 {
-    auto& gameState = GetGameState();
-    gameState.ResearchItemsInvented.insert(
-        gameState.ResearchItemsInvented.end(), std::make_move_iterator(gameState.ResearchItemsUninvented.begin()),
-        std::make_move_iterator(gameState.ResearchItemsUninvented.end()));
-    gameState.ResearchItemsUninvented.clear();
+    auto& gameState = getGameState();
+    gameState.researchItemsInvented.insert(
+        gameState.researchItemsInvented.end(), std::make_move_iterator(gameState.researchItemsUninvented.begin()),
+        std::make_move_iterator(gameState.researchItemsUninvented.end()));
+    gameState.researchItemsUninvented.clear();
 }
 
 /**
@@ -940,9 +940,9 @@ void ResearchItemsMakeAllResearched()
  */
 void ResearchItemsShuffle()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     std::shuffle(
-        std::begin(gameState.ResearchItemsUninvented), std::end(gameState.ResearchItemsUninvented),
+        std::begin(gameState.researchItemsUninvented), std::end(gameState.researchItemsUninvented),
         std::default_random_engine{});
 }
 
@@ -963,15 +963,15 @@ void ResearchItem::SetNull()
 
 bool ResearchItem::Exists() const
 {
-    auto& gameState = GetGameState();
-    for (auto const& researchItem : gameState.ResearchItemsUninvented)
+    auto& gameState = getGameState();
+    for (auto const& researchItem : gameState.researchItemsUninvented)
     {
         if (researchItem == *this)
         {
             return true;
         }
     }
-    for (auto const& researchItem : gameState.ResearchItemsInvented)
+    for (auto const& researchItem : gameState.researchItemsInvented)
     {
         if (researchItem == *this)
         {
@@ -1064,10 +1064,10 @@ static void ResearchMarkRideTypeAsSeen(const ResearchItem& researchItem)
 
 void ResearchDetermineFirstOfType()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     _seenRideType.reset();
 
-    for (const auto& researchItem : gameState.ResearchItemsInvented)
+    for (const auto& researchItem : gameState.researchItemsInvented)
     {
         if (researchItem.type != Research::EntryType::Ride)
             continue;
@@ -1080,40 +1080,40 @@ void ResearchDetermineFirstOfType()
         if (rtd.HasFlag(RtdFlag::listVehiclesSeparately))
             continue;
 
-        // The last research item will also be present in gameState.ResearchItemsInvented.
+        // The last research item will also be present in gameState.researchItemsInvented.
         // Avoid marking its ride type as "invented" prematurely.
-        if (gameState.ResearchLastItem.has_value() && !gameState.ResearchLastItem->IsNull()
-            && researchItem == gameState.ResearchLastItem.value())
+        if (gameState.researchLastItem.has_value() && !gameState.researchLastItem->IsNull()
+            && researchItem == gameState.researchLastItem.value())
             continue;
 
-        // The next research item is (sometimes?) also present in gameState.ResearchItemsInvented, even though it isn't invented
+        // The next research item is (sometimes?) also present in gameState.researchItemsInvented, even though it isn't invented
         // yet(!)
-        if (gameState.ResearchNextItem.has_value() && !gameState.ResearchNextItem->IsNull()
-            && researchItem == gameState.ResearchNextItem.value())
+        if (gameState.researchNextItem.has_value() && !gameState.researchNextItem->IsNull()
+            && researchItem == gameState.researchNextItem.value())
             continue;
 
         ResearchMarkRideTypeAsSeen(researchItem);
     }
 
-    if (gameState.ResearchLastItem.has_value())
+    if (gameState.researchLastItem.has_value())
     {
-        ResearchUpdateFirstOfType(&gameState.ResearchLastItem.value());
-        ResearchMarkRideTypeAsSeen(gameState.ResearchLastItem.value());
+        ResearchUpdateFirstOfType(&gameState.researchLastItem.value());
+        ResearchMarkRideTypeAsSeen(gameState.researchLastItem.value());
     }
-    if (gameState.ResearchNextItem.has_value())
+    if (gameState.researchNextItem.has_value())
     {
-        ResearchUpdateFirstOfType(&gameState.ResearchNextItem.value());
-        ResearchMarkRideTypeAsSeen(gameState.ResearchNextItem.value());
+        ResearchUpdateFirstOfType(&gameState.researchNextItem.value());
+        ResearchMarkRideTypeAsSeen(gameState.researchNextItem.value());
     }
 
-    for (auto& researchItem : gameState.ResearchItemsUninvented)
+    for (auto& researchItem : gameState.researchItemsUninvented)
     {
-        // The next research item is (sometimes?) also present in gameState.ResearchItemsUninvented
-        if (gameState.ResearchNextItem.has_value() && !gameState.ResearchNextItem->IsNull()
-            && researchItem.baseRideType == gameState.ResearchNextItem.value().baseRideType)
+        // The next research item is (sometimes?) also present in gameState.researchItemsUninvented
+        if (gameState.researchNextItem.has_value() && !gameState.researchNextItem->IsNull()
+            && researchItem.baseRideType == gameState.researchNextItem.value().baseRideType)
         {
             // Copy the "first of type" flag.
-            researchItem.flags = gameState.ResearchNextItem->flags;
+            researchItem.flags = gameState.researchNextItem->flags;
             continue;
         }
 
