@@ -12,7 +12,6 @@
 #include "../../../ride/RideData.h"
 #include "../../../ride/Track.h"
 #include "../../../ride/TrackPaint.h"
-#include "../../../world/Map.h"
 #include "../../../world/tile_element/PathElement.h"
 #include "../../../world/tile_element/TileElement.h"
 #include "../../../world/tile_element/TrackElement.h"
@@ -156,13 +155,6 @@ static constexpr uint32_t miniature_railway_track_pieces_flat[4] = {
     SPR_MINIATURE_RAILWAY_FLAT_NW_SE,
 };
 
-static constexpr uint32_t miniature_railway_station_floor[4] = {
-    SPR_STATION_BASE_A_SW_NE,
-    SPR_STATION_BASE_A_NW_SE,
-    SPR_STATION_BASE_A_SW_NE,
-    SPR_STATION_BASE_A_NW_SE,
-};
-
 static constexpr uint32_t miniature_railway_track_pieces_flat_station[4] = {
     SPR_MINIATURE_RAILWAY_FLAT_NO_BASE_SW_NE,
     SPR_MINIATURE_RAILWAY_FLAT_NO_BASE_NW_SE,
@@ -318,7 +310,7 @@ static constexpr CoordsXYZ miniature_railway_track_pieces_right_eight_to_diag_bo
     {
         { 32, 32, 2 },
         { 34, 16, 2 },
-        { 16, 16, 2 },
+        { 14, 14, 2 },
         { 32, 34, 0 },
     },
     {
@@ -575,12 +567,12 @@ static constexpr uint32_t miniature_railway_track_pieces_diag_25_deg_up[4] = {
 
 static ImageId MiniatureRailwayTrackToGravel(ImageId imageId)
 {
-    return ImageId(imageId.GetIndex() - SPR_MINIATURE_RAILWAY_FLAT_SW_NE + SPR_G2_MINIATURE_RAILWAY_GRAVEL_SW_NE);
+    return ImageId(imageId.GetIndex() - SPR_MINIATURE_RAILWAY_FLAT_SW_NE + SPR_TRACKS_MINIATURE_RAILWAY_GRAVEL_SW_NE);
 }
 
 static ImageId MiniatureRailwayTrackToGrooved(ImageId imageId)
 {
-    return ImageId(imageId.GetIndex() - SPR_MINIATURE_RAILWAY_FLAT_SW_NE + SPR_G2_MINIATURE_RAILWAY_GROOVED_SW_NE);
+    return ImageId(imageId.GetIndex() - SPR_MINIATURE_RAILWAY_FLAT_SW_NE + SPR_TRACKS_MINIATURE_RAILWAY_GROOVED_SW_NE);
 }
 
 static ImageId MiniatureRailwayTrackToGroovedIndent(const TileElement* path, uint8_t direction, uint8_t rotation)
@@ -590,7 +582,7 @@ static ImageId MiniatureRailwayTrackToGroovedIndent(const TileElement* path, uin
         return ImageId(0);
     }
 
-    uint32_t imageIdAlt = SPR_G2_MINIATURE_RAILWAY_GROOVED_SW_NE;
+    uint32_t imageIdAlt = SPR_TRACKS_MINIATURE_RAILWAY_GROOVED_SW_NE;
 
     uint8_t correctedEdges = path->AsPath()->GetEdges();
     correctedEdges |= correctedEdges << 4;
@@ -601,12 +593,12 @@ static ImageId MiniatureRailwayTrackToGroovedIndent(const TileElement* path, uin
     {
         static constexpr uint32_t imageIds[2][2] = {
             {
-                SPR_G2_MINIATURE_RAILWAY_INSET_NW_SE,
-                SPR_G2_MINIATURE_RAILWAY_INSET_END_NW,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_NW_SE,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_END_NW,
             },
             {
-                SPR_G2_MINIATURE_RAILWAY_INSET_END_SE,
-                SPR_G2_MINIATURE_RAILWAY_INSET_END_NW_SE,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_END_SE,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_END_NW_SE,
             },
         };
         imageIdAlt = imageIds[(correctedEdges & 0x2) ? 0 : 1][(correctedEdges & 0x8) ? 0 : 1];
@@ -615,12 +607,12 @@ static ImageId MiniatureRailwayTrackToGroovedIndent(const TileElement* path, uin
     {
         static constexpr uint32_t imageIds[2][2] = {
             {
-                SPR_G2_MINIATURE_RAILWAY_INSET_SW_NE,
-                SPR_G2_MINIATURE_RAILWAY_INSET_END_SW,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_SW_NE,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_END_SW,
             },
             {
-                SPR_G2_MINIATURE_RAILWAY_INSET_END_NE,
-                SPR_G2_MINIATURE_RAILWAY_INSET_END_SW_NE,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_END_NE,
+                SPR_TRACKS_MINIATURE_RAILWAY_INSET_END_SW_NE,
             },
         };
         imageIdAlt = imageIds[(correctedEdges & 0x1) ? 0 : 1][(correctedEdges & 0x4) ? 0 : 1];
@@ -644,7 +636,7 @@ static void PaintMiniatureRailwayTrackFlat(
     }
 
     bool isSupported = WoodenASupportsPaintSetupRotated(
-        session, supportType.wooden, WoodenSupportSubType::NeSw, direction, height, session.SupportColours);
+        session, supportType.wooden, WoodenSupportSubType::neSw, direction, height, session.SupportColours);
     ImageId imageId, imageIdAlt;
 
     // In the following 3 calls to PaintAddImageAsParentRotated/PaintAddImageAsChildRotated, we add 1 to the
@@ -672,7 +664,7 @@ static void PaintMiniatureRailwayTrackFlat(
             imageIdAlt = MiniatureRailwayTrackToGroovedIndent(
                 session.PathElementOnSameHeight, direction, session.CurrentRotation);
             PaintAddImageAsChildRotated(
-                session, direction, imageIdAlt.WithTransparency(FilterPaletteID::PaletteDarken2), { 0, 6, height },
+                session, direction, imageIdAlt.WithTransparency(FilterPaletteID::paletteDarken2), { 0, 6, height },
                 { { 0, 6, height + 2 }, { 32, 20, 2 } });
         }
     }
@@ -696,7 +688,7 @@ static void PaintMiniatureRailwayTrackFlat(
             imageIdAlt = MiniatureRailwayTrackToGroovedIndent(
                 session.PathElementOnSameHeight, direction, session.CurrentRotation);
             PaintAddImageAsParentRotated(
-                session, direction, imageIdAlt.WithTransparency(FilterPaletteID::PaletteDarken2), { 0, 6, height },
+                session, direction, imageIdAlt.WithTransparency(FilterPaletteID::paletteDarken2), { 0, 6, height },
                 { { 0, 6, height + 2 }, { 32, 20, 2 } });
         }
     }
@@ -712,21 +704,19 @@ static void PaintMiniatureRailwayStation(
     PaintSession& session, const Ride& ride, [[maybe_unused]] uint8_t trackSequence, uint8_t direction, int32_t height,
     const TrackElement& trackElement, SupportType supportType)
 {
-    ImageId imageId;
+    if (WoodenASupportsPaintSetupRotated(
+            session, supportType.wooden, WoodenSupportSubType::neSw, direction, height, session.SupportColours))
+    {
+        const ImageId imageId = session.SupportColours.WithIndex(miniature_railway_track_floor[direction]);
+        PaintAddImageAsChildRotated(session, direction, imageId, { 0, 0, height }, { { 0, 0, height }, { 32, 32, 0 } });
+    }
 
-    WoodenASupportsPaintSetupRotated(
-        session, supportType.wooden, WoodenSupportSubType::NeSw, direction, height, session.SupportColours);
-
-    imageId = GetStationColourScheme(session, trackElement).WithIndex(miniature_railway_station_floor[direction]);
-    PaintAddImageAsParentRotated(session, direction, imageId, { 0, 0, height - 2 }, { { 0, 2, height }, { 32, 28, 2 } });
-
-    imageId = session.TrackColours.WithIndex(miniature_railway_track_pieces_flat_station[direction]);
-    PaintAddImageAsChildRotated(session, direction, imageId, { 0, 6, height }, { { 0, 0, height }, { 32, 20, 2 } });
+    const ImageId imageId = session.TrackColours.WithIndex(miniature_railway_track_pieces_flat_station[direction]);
+    PaintAddImageAsParentRotated(session, direction, imageId, { 0, 6, height }, { { 0, 6, height + 1 }, { 32, 20, 1 } });
 
     TrackPaintUtilDrawStationTunnel(session, direction, height);
 
-    TrackPaintUtilDrawStation3(session, ride, direction, height + 2, height, trackElement);
-    // covers shouldn't be offset by +2
+    TrackPaintUtilDrawStation2(session, ride, direction, height, trackElement, StationBaseType::a, -2, 7, 9);
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
     PaintUtilSetGeneralSupportHeight(session, height + 30);
@@ -758,8 +748,8 @@ static void PaintMiniatureRailwayTrack25DegUp(
     }
 
     WoodenASupportsPaintSetupRotated(
-        session, supportType.wooden, WoodenSupportSubType::NeSw, direction, height, session.SupportColours,
-        WoodenSupportTransitionType::Up25DegRailway);
+        session, supportType.wooden, WoodenSupportSubType::neSw, direction, height, session.SupportColours,
+        WoodenSupportTransitionType::up25DegRailway);
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
     PaintUtilSetGeneralSupportHeight(session, height + 56);
@@ -791,8 +781,8 @@ static void PaintMiniatureRailwayTrackFlatTo25DegUp(
     }
 
     WoodenASupportsPaintSetupRotated(
-        session, supportType.wooden, WoodenSupportSubType::NeSw, direction, height, session.SupportColours,
-        WoodenSupportTransitionType::FlatToUp25DegRailway);
+        session, supportType.wooden, WoodenSupportSubType::neSw, direction, height, session.SupportColours,
+        WoodenSupportTransitionType::flatToUp25DegRailway);
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
     PaintUtilSetGeneralSupportHeight(session, height + 48);
@@ -824,8 +814,8 @@ static void PaintMiniatureRailwayTrack25DegUpToFlat(
     }
 
     WoodenASupportsPaintSetupRotated(
-        session, supportType.wooden, WoodenSupportSubType::NeSw, direction, height, session.SupportColours,
-        WoodenSupportTransitionType::Up25DegToFlatRailway);
+        session, supportType.wooden, WoodenSupportSubType::neSw, direction, height, session.SupportColours,
+        WoodenSupportTransitionType::up25DegToFlatRailway);
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
     PaintUtilSetGeneralSupportHeight(session, height + 40);
@@ -982,19 +972,19 @@ static constexpr uint32_t miniature_railway_right_quarter_turn_5_tiles_track_flo
 };
 
 static constexpr WoodenSupportSubType right_quarter_turn_5_supports_type[4][7] = {
-    { WoodenSupportSubType::NeSw, WoodenSupportSubType::Null, WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner0,
-      WoodenSupportSubType::Null, WoodenSupportSubType::Corner2, WoodenSupportSubType::NwSe },
-    { WoodenSupportSubType::NwSe, WoodenSupportSubType::Null, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1,
-      WoodenSupportSubType::Null, WoodenSupportSubType::Corner3, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::NeSw, WoodenSupportSubType::Null, WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner2,
-      WoodenSupportSubType::Null, WoodenSupportSubType::Corner0, WoodenSupportSubType::NwSe },
-    { WoodenSupportSubType::NwSe, WoodenSupportSubType::Null, WoodenSupportSubType::Corner1, WoodenSupportSubType::Corner3,
-      WoodenSupportSubType::Null, WoodenSupportSubType::Corner1, WoodenSupportSubType::NeSw },
+    { WoodenSupportSubType::neSw, WoodenSupportSubType::null, WoodenSupportSubType::corner2, WoodenSupportSubType::corner0,
+      WoodenSupportSubType::null, WoodenSupportSubType::corner2, WoodenSupportSubType::nwSe },
+    { WoodenSupportSubType::nwSe, WoodenSupportSubType::null, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1,
+      WoodenSupportSubType::null, WoodenSupportSubType::corner3, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::neSw, WoodenSupportSubType::null, WoodenSupportSubType::corner0, WoodenSupportSubType::corner2,
+      WoodenSupportSubType::null, WoodenSupportSubType::corner0, WoodenSupportSubType::nwSe },
+    { WoodenSupportSubType::nwSe, WoodenSupportSubType::null, WoodenSupportSubType::corner1, WoodenSupportSubType::corner3,
+      WoodenSupportSubType::null, WoodenSupportSubType::corner1, WoodenSupportSubType::neSw },
 };
 
 static constexpr WoodenSupportSubType miniature_railway_right_quarter_turn_5_tiles_sprite_map[] = {
-    WoodenSupportSubType::NeSw, WoodenSupportSubType::Null,    WoodenSupportSubType::NwSe,    WoodenSupportSubType::Corner0,
-    WoodenSupportSubType::Null, WoodenSupportSubType::Corner1, WoodenSupportSubType::Corner2,
+    WoodenSupportSubType::neSw, WoodenSupportSubType::null,    WoodenSupportSubType::nwSe,    WoodenSupportSubType::corner0,
+    WoodenSupportSubType::null, WoodenSupportSubType::corner1, WoodenSupportSubType::corner2,
 };
 
 /** rct2: 0x008AD140 */
@@ -1002,7 +992,7 @@ static void PaintMiniatureRailwayTrackRightQuarterTurn5Tiles(
     PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
     const TrackElement& trackElement, SupportType supportType)
 {
-    if (right_quarter_turn_5_supports_type[direction][trackSequence] != WoodenSupportSubType::Null)
+    if (right_quarter_turn_5_supports_type[direction][trackSequence] != WoodenSupportSubType::null)
     {
         bool isSupported = WoodenASupportsPaintSetup(
             session, supportType.wooden, right_quarter_turn_5_supports_type[direction][trackSequence], height,
@@ -1061,26 +1051,25 @@ static void PaintMiniatureRailwayTrackRightQuarterTurn5Tiles(
             blockedSegments = kSegmentsAll;
             break;
         case 1:
-            blockedSegments = EnumsToFlags(PaintSegment::topCorner, PaintSegment::topLeftSide, PaintSegment::topRightSide);
+            blockedSegments = EnumsToFlags(PaintSegment::top, PaintSegment::topLeft, PaintSegment::topRight);
             break;
         case 2:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomLeftSide, PaintSegment::centre, PaintSegment::bottomRightSide, PaintSegment::rightCorner,
-                PaintSegment::bottomCorner, PaintSegment::topRightSide);
+                PaintSegment::bottomLeft, PaintSegment::centre, PaintSegment::bottomRight, PaintSegment::right,
+                PaintSegment::bottom, PaintSegment::topRight);
             break;
         case 3:
             blockedSegments = EnumsToFlags(
-                PaintSegment::topCorner, PaintSegment::leftCorner, PaintSegment::rightCorner, PaintSegment::centre,
-                PaintSegment::topLeftSide, PaintSegment::topRightSide, PaintSegment::bottomLeftSide,
-                PaintSegment::bottomRightSide);
+                PaintSegment::top, PaintSegment::left, PaintSegment::right, PaintSegment::centre, PaintSegment::topLeft,
+                PaintSegment::topRight, PaintSegment::bottomLeft, PaintSegment::bottomRight);
             break;
         case 4:
-            blockedSegments = EnumsToFlags(PaintSegment::topCorner, PaintSegment::topLeftSide, PaintSegment::topRightSide);
+            blockedSegments = EnumsToFlags(PaintSegment::top, PaintSegment::topLeft, PaintSegment::topRight);
             break;
         case 5:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomRightSide, PaintSegment::centre, PaintSegment::bottomLeftSide, PaintSegment::leftCorner,
-                PaintSegment::bottomCorner, PaintSegment::topLeftSide);
+                PaintSegment::bottomRight, PaintSegment::centre, PaintSegment::bottomLeft, PaintSegment::left,
+                PaintSegment::bottom, PaintSegment::topLeft);
             break;
         case 6:
             blockedSegments = kSegmentsAll;
@@ -1103,10 +1092,10 @@ static void PaintMiniatureRailwayTrackLeftQuarterTurn5Tiles(
 }
 
 static constexpr WoodenSupportSubType s_bend_left_supports_type[kNumOrthogonalDirections][4] = {
-    { WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner2, WoodenSupportSubType::NwSe },
-    { WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner2, WoodenSupportSubType::NwSe },
+    { WoodenSupportSubType::neSw, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::nwSe, WoodenSupportSubType::corner0, WoodenSupportSubType::corner2, WoodenSupportSubType::nwSe },
+    { WoodenSupportSubType::neSw, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::nwSe, WoodenSupportSubType::corner0, WoodenSupportSubType::corner2, WoodenSupportSubType::nwSe },
 };
 
 static constexpr uint32_t miniature_railway_s_bend_left_tiles_track_floor[2][4] = {
@@ -1196,13 +1185,13 @@ static void PaintMiniatureRailwayTrackSBendLeft(
             break;
         case 1:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomLeftSide, PaintSegment::centre, PaintSegment::topRightSide, PaintSegment::leftCorner,
-                PaintSegment::topLeftSide, PaintSegment::topCorner);
+                PaintSegment::bottomLeft, PaintSegment::centre, PaintSegment::topRight, PaintSegment::left,
+                PaintSegment::topLeft, PaintSegment::top);
             break;
         case 2:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomLeftSide, PaintSegment::centre, PaintSegment::topRightSide, PaintSegment::bottomCorner,
-                PaintSegment::bottomRightSide, PaintSegment::rightCorner);
+                PaintSegment::bottomLeft, PaintSegment::centre, PaintSegment::topRight, PaintSegment::bottom,
+                PaintSegment::bottomRight, PaintSegment::right);
             break;
         case 3:
             blockedSegments = kSegmentsAll;
@@ -1214,10 +1203,10 @@ static void PaintMiniatureRailwayTrackSBendLeft(
 }
 
 static constexpr WoodenSupportSubType s_bend_right_supports_type[kNumOrthogonalDirections][4] = {
-    { WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner0, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1, WoodenSupportSubType::NwSe },
-    { WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner0, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1, WoodenSupportSubType::NwSe },
+    { WoodenSupportSubType::neSw, WoodenSupportSubType::corner2, WoodenSupportSubType::corner0, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::nwSe, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1, WoodenSupportSubType::nwSe },
+    { WoodenSupportSubType::neSw, WoodenSupportSubType::corner2, WoodenSupportSubType::corner0, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::nwSe, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1, WoodenSupportSubType::nwSe },
 };
 
 static constexpr uint32_t miniature_railway_s_bend_right_tiles_track_floor[2][4] = {
@@ -1307,13 +1296,13 @@ static void PaintMiniatureRailwayTrackSBendRight(
             break;
         case 1:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomLeftSide, PaintSegment::centre, PaintSegment::topRightSide, PaintSegment::bottomCorner,
-                PaintSegment::bottomRightSide, PaintSegment::rightCorner);
+                PaintSegment::bottomLeft, PaintSegment::centre, PaintSegment::topRight, PaintSegment::bottom,
+                PaintSegment::bottomRight, PaintSegment::right);
             break;
         case 2:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomLeftSide, PaintSegment::centre, PaintSegment::topRightSide, PaintSegment::leftCorner,
-                PaintSegment::topLeftSide, PaintSegment::topCorner);
+                PaintSegment::bottomLeft, PaintSegment::centre, PaintSegment::topRight, PaintSegment::left,
+                PaintSegment::topLeft, PaintSegment::top);
             break;
         case 3:
             blockedSegments = kSegmentsAll;
@@ -1379,7 +1368,7 @@ static void PaintMiniatureRailwayTrackRightQuarterTurn3Tiles(
     if (trackSequence != 1 && trackSequence != 2)
     {
         isSupported = WoodenASupportsPaintSetupRotated(
-            session, supportType.wooden, WoodenSupportSubType::Corner2, direction, height, session.SupportColours);
+            session, supportType.wooden, WoodenSupportSubType::corner2, direction, height, session.SupportColours);
     }
     if (!isSupported)
     {
@@ -1391,7 +1380,7 @@ static void PaintMiniatureRailwayTrackRightQuarterTurn3Tiles(
         // The following piece was missing in vanilla RCT2
         if (trackSequence == 1 && direction == 0)
         {
-            auto imageId = session.TrackColours.WithIndex(SPR_G2_MINIATURE_RAILWAY_QUARTER_TURN_3_TILES_SW_SE_PART_3);
+            auto imageId = session.TrackColours.WithIndex(SPR_TRACKS_MINIATURE_RAILWAY_QUARTER_TURN_3_TILES_SW_SE_PART_3);
             PaintAddImageAsParent(session, imageId, { 0, 0, height }, { { 0, 0, height }, { 8, 8, 2 } });
         }
     }
@@ -1423,7 +1412,7 @@ static void PaintMiniatureRailwayTrackRightQuarterTurn3Tiles(
             break;
         case 2:
             blockedSegments = EnumsToFlags(
-                PaintSegment::bottomLeftSide, PaintSegment::centre, PaintSegment::bottomRightSide, PaintSegment::bottomCorner);
+                PaintSegment::bottomLeft, PaintSegment::centre, PaintSegment::bottomRight, PaintSegment::bottom);
             break;
         case 3:
             blockedSegments = kSegmentsAll;
@@ -1547,14 +1536,14 @@ static void PaintMiniatureRailwayTrackLeftEighthToDiag(
     const TrackElement& trackElement, SupportType supportType)
 {
     static constexpr WoodenSupportSubType supportSubType[kNumOrthogonalDirections][5] = {
-        { WoodenSupportSubType::NeSw, WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner1, WoodenSupportSubType::Corner3,
-          WoodenSupportSubType::NwSe },
-        { WoodenSupportSubType::NwSe, WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner0,
-          WoodenSupportSubType::NeSw },
-        { WoodenSupportSubType::NeSw, WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1,
-          WoodenSupportSubType::NwSe },
-        { WoodenSupportSubType::NwSe, WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner2,
-          WoodenSupportSubType::NeSw },
+        { WoodenSupportSubType::neSw, WoodenSupportSubType::neSw, WoodenSupportSubType::corner1, WoodenSupportSubType::corner3,
+          WoodenSupportSubType::nwSe },
+        { WoodenSupportSubType::nwSe, WoodenSupportSubType::nwSe, WoodenSupportSubType::corner2, WoodenSupportSubType::corner0,
+          WoodenSupportSubType::neSw },
+        { WoodenSupportSubType::neSw, WoodenSupportSubType::neSw, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1,
+          WoodenSupportSubType::nwSe },
+        { WoodenSupportSubType::nwSe, WoodenSupportSubType::nwSe, WoodenSupportSubType::corner0, WoodenSupportSubType::corner2,
+          WoodenSupportSubType::neSw },
     };
 
     bool isSupported = false;
@@ -1611,7 +1600,9 @@ static void PaintMiniatureRailwayTrackLeftEighthToDiag(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
+
+    if (trackSequence != 4 || !isRightEighthToOrthog)
+        PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
 }
 
 static constexpr uint32_t kFloorPiecesRightEighthToDiag[4][5] = {
@@ -1663,7 +1654,7 @@ static constexpr CoordsXYZ kFloorPiecesRightEighthToDiagBounds[4][5] = {
     {
         { 32, 32, 2 },
         { 34, 16, 2 },
-        { 16, 16, 2 },
+        { 14, 14, 2 },
         { 16, 16, 0 },
         { 32, 34, 0 },
     },
@@ -1713,14 +1704,14 @@ static void PaintMiniatureRailwayTrackRightEighthToDiag(
     const TrackElement& trackElement, SupportType supportType)
 {
     static constexpr WoodenSupportSubType supportSubType[kNumOrthogonalDirections][5] = {
-        { WoodenSupportSubType::NeSw, WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner2,
-          WoodenSupportSubType::NwSe },
-        { WoodenSupportSubType::NwSe, WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner1, WoodenSupportSubType::Corner3,
-          WoodenSupportSubType::NeSw },
-        { WoodenSupportSubType::NeSw, WoodenSupportSubType::NeSw, WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner0,
-          WoodenSupportSubType::NwSe },
-        { WoodenSupportSubType::NwSe, WoodenSupportSubType::NwSe, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1,
-          WoodenSupportSubType::NeSw },
+        { WoodenSupportSubType::neSw, WoodenSupportSubType::neSw, WoodenSupportSubType::corner0, WoodenSupportSubType::corner2,
+          WoodenSupportSubType::nwSe },
+        { WoodenSupportSubType::nwSe, WoodenSupportSubType::nwSe, WoodenSupportSubType::corner1, WoodenSupportSubType::corner3,
+          WoodenSupportSubType::neSw },
+        { WoodenSupportSubType::neSw, WoodenSupportSubType::neSw, WoodenSupportSubType::corner2, WoodenSupportSubType::corner0,
+          WoodenSupportSubType::nwSe },
+        { WoodenSupportSubType::nwSe, WoodenSupportSubType::nwSe, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1,
+          WoodenSupportSubType::neSw },
     };
 
     bool isSupported = false;
@@ -1777,7 +1768,10 @@ static void PaintMiniatureRailwayTrackRightEighthToDiag(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
+
+    // Fixes #5281.
+    if (trackSequence != 4 || !isLeftEighthToOrthog)
+        PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
 }
 
 /** rct2: 0x008AD1E0 */
@@ -1801,10 +1795,10 @@ static void PaintMiniatureRailwayTrackRightEighthToOrthogonal(
 }
 
 static constexpr WoodenSupportSubType kDiagSupportTypes[kNumOrthogonalDirections][4] = {
-    { WoodenSupportSubType::Null, WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner2, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::Null, WoodenSupportSubType::Corner1, WoodenSupportSubType::Corner3, WoodenSupportSubType::NwSe },
-    { WoodenSupportSubType::Null, WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner0, WoodenSupportSubType::NeSw },
-    { WoodenSupportSubType::Null, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner1, WoodenSupportSubType::NwSe },
+    { WoodenSupportSubType::null, WoodenSupportSubType::corner0, WoodenSupportSubType::corner2, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::null, WoodenSupportSubType::corner1, WoodenSupportSubType::corner3, WoodenSupportSubType::nwSe },
+    { WoodenSupportSubType::null, WoodenSupportSubType::corner2, WoodenSupportSubType::corner0, WoodenSupportSubType::neSw },
+    { WoodenSupportSubType::null, WoodenSupportSubType::corner3, WoodenSupportSubType::corner1, WoodenSupportSubType::nwSe },
 };
 
 struct FloorDescriptor
@@ -1835,7 +1829,7 @@ static void MiniatureRailwayTrackDiagFlat(
     CoordsXY floorBoundSize;
     CoordsXY floorBoundOffset;
 
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -1871,7 +1865,10 @@ static void MiniatureRailwayTrackDiagFlat(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
+
+    // Fixes #5281.
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
 }
 
 /** rct2: 0x008AD230 */
@@ -1893,7 +1890,7 @@ static void MiniatureRailwayTrackDiag25DegUp(
     CoordsXY floorBoundOffset;
 
     auto supportSubType = kDiagSupportTypes[direction][trackSequence];
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -1952,7 +1949,10 @@ static void MiniatureRailwayTrackDiag25DegUp(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + 56);
+
+    // Fixes #5281
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + 56);
 }
 
 /** rct2: 0x008AD210 */
@@ -1967,7 +1967,7 @@ static void MiniatureRailwayTrackDiagFlatTo25DegUp(
     CoordsXY floorBoundOffset;
 
     auto supportSubType = kDiagSupportTypes[direction][trackSequence];
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -2003,7 +2003,9 @@ static void MiniatureRailwayTrackDiagFlatTo25DegUp(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + 48);
+
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + 48);
 }
 
 /** rct2: 0x008AD220 */
@@ -2025,7 +2027,7 @@ static void MiniatureRailwayTrackDiag25DegUpToFlat(
     CoordsXY floorBoundSize;
     CoordsXY floorBoundOffset;
 
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -2082,7 +2084,9 @@ static void MiniatureRailwayTrackDiag25DegUpToFlat(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + 56);
+
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + 56);
 }
 
 /** rct2: 0x008AD260 */
@@ -2104,7 +2108,7 @@ static void MiniatureRailwayTrackDiag25DegDown(
     CoordsXY floorBoundOffset;
     auto supportSubType = kDiagSupportTypes[direction][trackSequence];
 
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -2160,7 +2164,10 @@ static void MiniatureRailwayTrackDiag25DegDown(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + 56);
+
+    // Fixes #5281
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + 56);
 }
 
 /** rct2: 0x008AD240 */
@@ -2181,7 +2188,7 @@ static void MiniatureRailwayTrackDiagFlatTo25DegDown(
     CoordsXY floorBoundOffset;
     auto supportSubType = kDiagSupportTypes[direction][trackSequence];
 
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -2237,7 +2244,10 @@ static void MiniatureRailwayTrackDiagFlatTo25DegDown(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + 56);
+
+    // Fixes #5281,
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + 56);
 }
 
 static void MiniatureRailwayTrackDiag25DegDownToFlat(
@@ -2250,7 +2260,7 @@ static void MiniatureRailwayTrackDiag25DegDownToFlat(
     CoordsXY floorBoundOffset;
     auto supportSubType = kDiagSupportTypes[direction][trackSequence];
 
-    if (supportSubType != WoodenSupportSubType::Null)
+    if (supportSubType != WoodenSupportSubType::null)
     {
         const auto enumValue = EnumValue(supportSubType);
         floorImage = kFloors[enumValue].image_id;
@@ -2286,7 +2296,10 @@ static void MiniatureRailwayTrackDiag25DegDownToFlat(
     }
 
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
-    PaintUtilSetGeneralSupportHeight(session, height + 48);
+
+    // Fixes #5281.
+    if (supportSubType != WoodenSupportSubType::null)
+        PaintUtilSetGeneralSupportHeight(session, height + 48);
 }
 
 /**
