@@ -623,7 +623,7 @@ constexpr RideTypeDescriptor kDummyRTD =
     .AvailableBreakdowns = 0,
     .Heights = { 12, 64, 0, 0, },
     .MaxMass = 255,
-    .LiftData = { OpenRCT2::Audio::SoundId::Null, 5, 5 },
+    .LiftData = { OpenRCT2::Audio::SoundId::null, 5, 5 },
     .RatingsMultipliers = { 0, 0, 0 },
     .UpkeepCosts = { 50, 1, 0, 0, 0, 0 },
     .BuildCosts = { 0.00_GBP, 0.00_GBP, 1 },
