@@ -39,7 +39,7 @@ constexpr RideTypeDescriptor ClassicStandUpRollerCoasterRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION) | (1 << BREAKDOWN_BRAKES_FAILURE),
     .Heights = { 30, 24, 9, 11, },
     .MaxMass = 18,
-    .LiftData = { Audio::SoundId::LiftClassic, 4, 6 },
+    .LiftData = { Audio::SoundId::liftClassic, 4, 6 },
     .RatingsMultipliers = { 50, 30, 10 },
     .UpkeepCosts = { 40, 20, 80, 10, 3, 10 },
     .BuildCosts = { 50.00_GBP, 2.50_GBP, 50, },
