@@ -40,7 +40,7 @@ constexpr RideTypeDescriptor ClassicWoodenRollerCoasterRTD =
    .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION) | (1 << BREAKDOWN_BRAKES_FAILURE),
    .Heights = { 24, 24, 8, 11, },
    .MaxMass = 19,
-   .LiftData = { Audio::SoundId::LiftWood, 3, 5 },
+   .LiftData = { Audio::SoundId::liftWood, 3, 5 },
    .RatingsMultipliers = { 52, 33, 4 },
    .UpkeepCosts = { 40, 20, 80, 10, 3, 10 },
    .BuildCosts = {37.50_GBP, 3.50_GBP, 50,  },
