@@ -41,7 +41,7 @@ constexpr RideTypeDescriptor CorkscrewRollerCoasterRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION) | (1 << BREAKDOWN_BRAKES_FAILURE),
     .Heights = { 28, 24, 8, 11, },
     .MaxMass = 18,
-    .LiftData = { Audio::SoundId::LiftArrow, 4, 6 },
+    .LiftData = { Audio::SoundId::liftArrow, 4, 6 },
     .RatingsMultipliers = { 50, 30, 10 },
     .UpkeepCosts = { 40, 20, 80, 11, 3, 10 },
     .BuildCosts = { 52.50_GBP, 2.50_GBP, 50, },
