@@ -41,7 +41,7 @@ constexpr RideTypeDescriptor InvertedImpulseCoasterRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION),
     .Heights = { 45, 40, 29, 8, },
     .MaxMass = 23,
-    .LiftData = { Audio::SoundId::LiftClassic, 4, 7 },
+    .LiftData = { Audio::SoundId::liftClassic, 4, 7 },
     .RatingsMultipliers = { 50, 30, 10 },
     .UpkeepCosts = { 180, 20, 80, 11, 3, 10 },
     .BuildCosts = { 62.50_GBP, 2.50_GBP, 25, },
