@@ -39,11 +39,11 @@ constexpr RideTypeDescriptor CrookedHouseRTD =
     .AvailableBreakdowns = 0,
     .Heights = { 16, 96, 3, 2, },
     .MaxMass = 255,
-    .LiftData = { Audio::SoundId::Null, 5, 5 },
+    .LiftData = { Audio::SoundId::null, 5, 5 },
     .RatingsMultipliers = { 15, 8, 0 },
     .UpkeepCosts = { 30, 1, 0, 0, 0, 0 },
     .BuildCosts = { 32.50_GBP, 1.00_GBP, 1, },
-    .DefaultPrices = { 6, 0 },
+    .DefaultPrices = { 10, 0 },
     .DefaultMusic = kMusicObjectGentle,
     .PhotoItem = ShopItem::Photo,
     .BonusValue = 22,
