@@ -40,7 +40,7 @@ constexpr RideTypeDescriptor SpiralSlideRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT),
     .Heights = { 15, 128, 0, 2, },
     .MaxMass = 255,
-    .LiftData = { Audio::SoundId::Null, 5, 5 },
+    .LiftData = { Audio::SoundId::null, 5, 5 },
     .RatingsMultipliers = { 50, 10, 0 },
     .UpkeepCosts = { 50, 1, 0, 0, 0, 0 },
     .BuildCosts = { 82.50_GBP, 1.00_GBP, 1, },
