@@ -41,7 +41,7 @@ constexpr RideTypeDescriptor LogFlumeRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_CONTROL_FAILURE),
     .Heights = { 10, 24, 7, 9, },
     .MaxMass = 255,
-    .LiftData = { Audio::SoundId::LiftFlume, 5, 5 },
+    .LiftData = { Audio::SoundId::liftFlume, 5, 5 },
     .RatingsMultipliers = { 80, 34, 6 },
     .UpkeepCosts = { 80, 20, 0, 9, 0, 10 },
     .BuildCosts = { 22.50_GBP, 2.50_GBP, 40, },
