@@ -34,6 +34,7 @@
 #include "../object/SmallSceneryEntry.h"
 #include "../object/WallSceneryEntry.h"
 #include "Footpath.h"
+#include "Map.h"
 #include "Park.h"
 #include "tile_element/PathElement.h"
 #include "tile_element/SmallSceneryElement.h"
@@ -74,7 +75,7 @@ LargeSceneryText::LargeSceneryText(const RCTLargeSceneryText& original)
         offset[i].x = original.offset[i].x;
         offset[i].y = original.offset[i].y;
     }
-    max_width = original.max_width;
+    maxWidth = original.maxWidth;
     flags = original.flags;
     num_images = original.num_images;
     for (size_t i = 0; i < std::size(original.glyphs); i++)
@@ -133,7 +134,7 @@ void SceneryUpdateTile(const CoordsXY& sceneryPos)
     {
         // Ghosts are purely this-client-side and should not cause any interaction,
         // as that may lead to a desync.
-        if (NetworkGetMode() != NETWORK_MODE_NONE)
+        if (Network::GetMode() != Network::Mode::none)
         {
             if (tileElement->IsGhost())
                 continue;
@@ -233,6 +234,8 @@ void SmallSceneryElement::UpdateAge(const CoordsXY& sceneryPos)
  */
 void SceneryRemoveGhostToolPlacement()
 {
+    auto& gameState = getGameState();
+
     if (gSceneryGhostType & SCENERY_GHOST_FLAG_0)
     {
         gSceneryGhostType &= ~SCENERY_GHOST_FLAG_0;
@@ -241,7 +244,7 @@ void SceneryRemoveGhostToolPlacement()
             gSceneryGhostPosition, gSceneryQuadrant, gSceneryPlaceObject.EntryIndex);
         removeSceneryAction.SetFlags(
             GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-        removeSceneryAction.Execute();
+        removeSceneryAction.Execute(gameState);
     }
 
     if (gSceneryGhostType & SCENERY_GHOST_FLAG_1)
@@ -263,7 +266,7 @@ void SceneryRemoveGhostToolPlacement()
             auto footpathAdditionRemoveAction = GameActions::FootpathAdditionRemoveAction(gSceneryGhostPosition);
             footpathAdditionRemoveAction.SetFlags(
                 GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-            GameActions::Execute(&footpathAdditionRemoveAction);
+            GameActions::Execute(&footpathAdditionRemoveAction, gameState);
             break;
         } while (!(tileElement++)->IsLastForTile());
     }
@@ -275,7 +278,7 @@ void SceneryRemoveGhostToolPlacement()
         CoordsXYZD wallLocation = { gSceneryGhostPosition, gSceneryGhostWallRotation };
         auto wallRemoveAction = GameActions::WallRemoveAction(wallLocation);
         wallRemoveAction.SetFlags(GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-        wallRemoveAction.Execute();
+        wallRemoveAction.Execute(gameState);
     }
 
     if (gSceneryGhostType & SCENERY_GHOST_FLAG_3)
@@ -285,7 +288,7 @@ void SceneryRemoveGhostToolPlacement()
         auto removeSceneryAction = GameActions::LargeSceneryRemoveAction({ gSceneryGhostPosition, gSceneryPlaceRotation }, 0);
         removeSceneryAction.SetFlags(
             GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-        removeSceneryAction.Execute();
+        removeSceneryAction.Execute(gameState);
     }
 
     if (gSceneryGhostType & SCENERY_GHOST_FLAG_4)
@@ -295,7 +298,7 @@ void SceneryRemoveGhostToolPlacement()
         auto removeSceneryAction = GameActions::BannerRemoveAction({ gSceneryGhostPosition, gSceneryPlaceRotation });
         removeSceneryAction.SetFlags(
             GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
-        GameActions::Execute(&removeSceneryAction);
+        GameActions::Execute(&removeSceneryAction, gameState);
     }
 }
 
